@@ -17,8 +17,24 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
+
+/**
+ * SECTION:mrp-calendar
+ * @Short_description: represents a calendar in the project.
+ * @Title: MrpCalendar
+ * @include: libplanner/mrp-calendar.h
+ *
+ * A calendar contains the information on working/nonworking time for
+ * resources. A calendar has a default week, specifying the day types
+ * (#MrpDay) used for each day of the week by default.
+ *
+ *
+ * Day types can be overriden so that a working day
+ * has another set of working time intervals per calendar. Certain dates
+ * can be overridden to use another day type as well.
  */
 
 #include <config.h>
@@ -44,7 +60,11 @@ enum {
 	LAST_SIGNAL
 };
 
-struct _MrpCalendarPriv {
+struct _MrpCalendar {
+	MrpObject        parent;
+};
+
+typedef struct {
 	MrpProject  *project;
 	gchar       *name;
 
@@ -60,7 +80,9 @@ struct _MrpCalendarPriv {
 
 	/* This can override single days and is hashed on the date */
 	GHashTable  *days;
-};
+} MrpCalendarPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (MrpCalendar, mrp_calendar, MRP_TYPE_OBJECT)
 
 struct _MrpInterval
 {
@@ -71,17 +93,6 @@ struct _MrpInterval
         guint           ref_count;
 };
 
-static void         calendar_class_init      (MrpCalendarClass *class);
-static void         calendar_init            (MrpCalendar      *module);
-static void         calendar_finalize        (GObject          *object);
-static void         calendar_set_property    (GObject          *object,
-					      guint             prop_id,
-					      const GValue     *value,
-					      GParamSpec       *pspec);
-static void         calendar_get_property    (GObject          *object,
-					      guint             prop_id,
-					      GValue           *value,
-					      GParamSpec       *pspec);
 static MrpDay *     calendar_get_default_day (MrpCalendar      *calendar,
 					      mrptime           date,
 					      gboolean          derive);
@@ -98,47 +109,86 @@ static void         calendar_emit_changed    (MrpCalendar      *calendar);
 static GList *      calendar_clean_intervals (GList            *list);
 
 
-
-static MrpObjectClass *parent_class;
 static guint           signals[LAST_SIGNAL];
 
-GType
-mrp_calendar_get_type (void)
+static void
+mrp_calendar_finalize (GObject *object)
 {
-	static GType object_type = 0;
+	MrpCalendar     *calendar = MRP_CALENDAR (object);
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 
-	if (!object_type) {
-		static const GTypeInfo object_info = {
-			sizeof (MrpCalendarClass),
-			NULL,		/* base_init */
-			NULL,		/* base_finalize */
-			(GClassInitFunc) calendar_class_init,
-			NULL,		/* class_finalize */
-			NULL,		/* class_data */
-			sizeof (MrpCalendar),
-			0,              /* n_preallocs */
-			(GInstanceInitFunc) calendar_init,
-		};
+	g_hash_table_destroy (priv->days);
+	g_hash_table_destroy (priv->day_intervals);
 
-		object_type = g_type_register_static (MRP_TYPE_OBJECT,
-						      "MrpCalendar",
-						      &object_info, 0);
-	}
+	g_list_foreach (priv->children, (GFunc) g_object_unref, NULL);
+	g_list_free (priv->children);
 
-	return object_type;
+	g_free (priv->name);
+
+	g_free (priv);
+
+	G_OBJECT_CLASS (mrp_calendar_parent_class)->finalize (object);
 }
 
 static void
-calendar_class_init (MrpCalendarClass *klass)
+mrp_calendar_get_property (GObject    *object,
+                           guint       prop_id,
+                           GValue     *value,
+                           GParamSpec *pspec)
+{
+	MrpCalendar     *calendar = MRP_CALENDAR (object);
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
+
+	switch (prop_id) {
+	case PROP_NAME:
+		g_value_set_string (value, priv->name);
+		break;
+	case PROP_PROJECT:
+		g_value_set_object (value, priv->project);
+		break;
+
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
+static void
+mrp_calendar_set_property (GObject      *object,
+                           guint         prop_id,
+                           const GValue *value,
+                           GParamSpec   *pspec)
+{
+	MrpCalendar     *calendar = MRP_CALENDAR (object);
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
+
+	switch (prop_id) {
+	case PROP_NAME:
+		mrp_calendar_set_name (calendar, g_value_get_string (value));
+		break;
+	case PROP_PROJECT:
+		priv->project = MRP_PROJECT (g_value_get_pointer (value));
+		break;
+	default:
+		break;
+	}
+}
+
+static void
+mrp_calendar_class_init (MrpCalendarClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = MRP_OBJECT_CLASS (g_type_class_peek_parent (klass));
-
-	object_class->finalize     = calendar_finalize;
-	object_class->get_property = calendar_get_property;
-	object_class->set_property = calendar_set_property;
+	object_class->finalize     = mrp_calendar_finalize;
+	object_class->get_property = mrp_calendar_get_property;
+	object_class->set_property = mrp_calendar_set_property;
 
+	/**
+	 * MrpCalendar::calendar-changed:
+	 * @calendar: the object which received the signal.
+	 *
+	 * emitted when @calendar changes.
+	 */
 	signals[CALENDAR_CHANGED] =
 		g_signal_new ("calendar-changed",
 			      G_TYPE_FROM_CLASS (klass),
@@ -168,11 +218,9 @@ calendar_class_init (MrpCalendarClass *klass)
 }
 
 static void
-calendar_init (MrpCalendar *calendar)
+mrp_calendar_init (MrpCalendar *calendar)
 {
-	MrpCalendarPriv *priv;
-
-	priv = g_new0 (MrpCalendarPriv, 1);
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 
 	priv->name   = NULL;
 	priv->parent = NULL;
@@ -183,93 +231,16 @@ calendar_init (MrpCalendar *calendar)
 	priv->children = NULL;
 
 	priv->day_intervals = g_hash_table_new (NULL, NULL);
-
-	calendar->priv = priv;
-}
-
-static void
-calendar_finalize (GObject *object)
-{
-	MrpCalendar     *calendar;
-	MrpCalendarPriv *priv;
-
-	calendar = MRP_CALENDAR (object);
-	priv     = calendar->priv;
-
-	g_hash_table_destroy (priv->days);
-	g_hash_table_destroy (priv->day_intervals);
-
-	g_list_foreach (priv->children, (GFunc) g_object_unref, NULL);
-	g_list_free (priv->children);
-
-	g_free (priv->name);
-
-	g_free (priv);
-
-	if (G_OBJECT_CLASS (parent_class)->finalize) {
-		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
-	}
-}
-
-static void
-calendar_get_property (GObject    *object,
-		       guint       prop_id,
-		       GValue     *value,
-		       GParamSpec *pspec)
-{
-	MrpCalendar     *calendar;
-	MrpCalendarPriv *priv;
-
-	calendar = MRP_CALENDAR (object);
-	priv     = calendar->priv;
-
-	switch (prop_id) {
-	case PROP_NAME:
-		g_value_set_string (value, priv->name);
-		break;
-	case PROP_PROJECT:
-		g_value_set_object (value, priv->project);
-		break;
-
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-		break;
-	}
-}
-
-static void
-calendar_set_property (GObject         *object,
-		       guint            prop_id,
-		       const GValue    *value,
-		       GParamSpec      *pspec)
-{
-	MrpCalendar     *calendar;
-	MrpCalendarPriv *priv;
-
-	calendar = MRP_CALENDAR (object);
-	priv     = calendar->priv;
-
-	switch (prop_id) {
-	case PROP_NAME:
-		mrp_calendar_set_name (calendar, g_value_get_string (value));
-		break;
-	case PROP_PROJECT:
-		priv->project = MRP_PROJECT (g_value_get_pointer (value));
-		break;
-	default:
-		break;
-	}
 }
 
 static MrpDay *
 calendar_get_default_day (MrpCalendar *calendar, mrptime date, gboolean derive)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	gint             week_day;
 
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), 0);
 
-	priv     = calendar->priv;
 	week_day = mrp_time_day_of_week (date);
 
 	if (priv->default_days[week_day] == mrp_day_get_use_base ()) {
@@ -288,13 +259,11 @@ calendar_get_default_day (MrpCalendar *calendar, mrptime date, gboolean derive)
 static MrpDay *
 calendar_get_day (MrpCalendar *calendar, mrptime date, gboolean derive)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	MrpDay          *day;
 
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), 0);
 
-	priv = calendar->priv;
-
 	day = (MrpDay *) g_hash_table_lookup (priv->days,
 					      GINT_TO_POINTER ((int)date));
 	if (!day) {
@@ -311,11 +280,12 @@ calendar_get_day (MrpCalendar *calendar, mrptime date, gboolean derive)
 static MrpCalendar *
 calendar_new (const gchar *name, MrpCalendar *parent)
 {
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (parent);
 	MrpCalendar *calendar;
 
 	calendar = g_object_new (MRP_TYPE_CALENDAR,
 				 "name", name,
-				 "project", parent->priv->project,
+				 "project", priv->project,
 				 NULL);
 
 	calendar_add_child (parent, calendar);
@@ -326,27 +296,33 @@ calendar_new (const gchar *name, MrpCalendar *parent)
 static void
 calendar_add_child (MrpCalendar *parent, MrpCalendar *child)
 {
-	if (child->priv->project != parent->priv->project) {
+	MrpCalendarPrivate *parent_priv = mrp_calendar_get_instance_private (parent);
+	MrpCalendarPrivate *child_priv = mrp_calendar_get_instance_private (child);
+
+	if (child_priv->project != parent_priv->project) {
 		g_warning ("Trying to add child calendar from different project than the parent calendar");
 		return;
 	}
 
-	parent->priv->children = g_list_prepend (parent->priv->children,
+	parent_priv->children = g_list_prepend (parent_priv->children,
 						  g_object_ref (child));
 
-	child->priv->parent = parent;
+	child_priv->parent = parent;
 }
 
 static void
 calendar_reparent (MrpCalendar *new_parent, MrpCalendar *child)
 {
-	if (child->priv->parent) {
+	MrpCalendarPrivate *child_priv = mrp_calendar_get_instance_private (child);
+
+	if (child_priv->parent) {
 		MrpCalendar *parent;
 
-		parent = child->priv->parent;
-		parent->priv->children = g_list_remove (parent->priv->children,
+		parent = child_priv->parent;
+		MrpCalendarPrivate *old_parent_priv = mrp_calendar_get_instance_private (parent);
+		old_parent_priv->children = g_list_remove (old_parent_priv->children,
 							 child);
-		child->priv->parent = NULL;
+		child_priv->parent = NULL;
 	}
 
 	calendar_add_child (new_parent, child);
@@ -382,13 +358,14 @@ foreach_copy_day_intervals (gpointer     key,
 			    gpointer     value,
 			    MrpCalendar *copy)
 {
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (copy);
 	MrpDay *day = key;
 	GList *list;
 
 	list = g_list_copy (value);
 	g_list_foreach (list, (GFunc) mrp_interval_ref, NULL);
 
-	g_hash_table_insert (copy->priv->day_intervals, day, list);
+	g_hash_table_insert (priv->day_intervals, day, list);
 }
 
 static void
@@ -396,9 +373,11 @@ foreach_copy_days (gpointer     key,
 		   gpointer     value,
 		   MrpCalendar *copy)
 {
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (copy);
+
 	MrpDay *day = value;
 
-	g_hash_table_insert (copy->priv->days, key, mrp_day_ref (day));
+	g_hash_table_insert (priv->days, key, mrp_day_ref (day));
 }
 
 /**
@@ -407,16 +386,16 @@ foreach_copy_days (gpointer     key,
  * @parent: a #MrpCalendar to inherit from
  *
  * Add @calendar to the project
- *
- * Return value:
  **/
 void
 mrp_calendar_add (MrpCalendar *calendar, MrpCalendar *parent)
 {
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
+
 	calendar_add_child (parent, calendar);
 
-	imrp_project_signal_calendar_tree_changed (calendar->priv->project);
-	imrp_project_set_needs_saving (calendar->priv->project, TRUE);
+	imrp_project_signal_calendar_tree_changed (priv->project);
+	imrp_project_set_needs_saving (priv->project, TRUE);
 }
 
 /**
@@ -432,26 +411,28 @@ mrp_calendar_add (MrpCalendar *calendar, MrpCalendar *parent)
 MrpCalendar *
 mrp_calendar_copy (const gchar *name, MrpCalendar *calendar)
 {
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	MrpCalendar *parent, *ret_val;
 
-	parent = mrp_project_get_root_calendar (calendar->priv->project);
+	parent = mrp_project_get_root_calendar (priv->project);
 
 	ret_val = calendar_new (name, parent);
+	MrpCalendarPrivate *ret_val_priv = mrp_calendar_get_instance_private (ret_val);
 
- 	memcpy (ret_val->priv->default_days,
- 		calendar->priv->default_days,
+ 	memcpy (ret_val_priv->default_days,
+		priv->default_days,
  		7 * sizeof (MrpDay *));
 
-	g_hash_table_foreach (calendar->priv->day_intervals,
+	g_hash_table_foreach (priv->day_intervals,
 			      (GHFunc) foreach_copy_day_intervals,
 			      ret_val);
 
-	g_hash_table_foreach (calendar->priv->days,
+	g_hash_table_foreach (priv->days,
 			      (GHFunc) foreach_copy_days,
 			      ret_val);
 
-	imrp_project_signal_calendar_tree_changed (calendar->priv->project);
-	imrp_project_set_needs_saving (calendar->priv->project, TRUE);
+	imrp_project_signal_calendar_tree_changed (priv->project);
+	imrp_project_set_needs_saving (priv->project, TRUE);
 
 	return ret_val;
 }
@@ -476,13 +457,14 @@ mrp_calendar_derive (const gchar *name, MrpCalendar *parent)
 	g_return_val_if_fail (MRP_IS_CALENDAR (parent), NULL);
 
 	ret_val = calendar_new (name, parent);
+	MrpCalendarPrivate *ret_val_priv = mrp_calendar_get_instance_private (ret_val);
 
 	for (i = 0; i < 7; ++i) {
-		ret_val->priv->default_days[i] = mrp_day_get_use_base ();
+		ret_val_priv->default_days[i] = mrp_day_get_use_base ();
 	}
 
-	imrp_project_signal_calendar_tree_changed (ret_val->priv->project);
-	imrp_project_set_needs_saving (ret_val->priv->project, TRUE);
+	imrp_project_signal_calendar_tree_changed (ret_val_priv->project);
+	imrp_project_set_needs_saving (ret_val_priv->project, TRUE);
 
 	return ret_val;
 }
@@ -492,20 +474,22 @@ mrp_calendar_derive (const gchar *name, MrpCalendar *parent)
  * @new_parent: the new parent
  * @child: an #MrpCalendar
  *
- * Changes the parent of @calendar so that it inherits @new_parent, instead of
+ * Changes the parent of @child so that it inherits @new_parent, instead of
  * its old parent.
  *
  **/
 void
 mrp_calendar_reparent (MrpCalendar *new_parent, MrpCalendar *child)
 {
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (new_parent);
+
 	g_return_if_fail (MRP_IS_CALENDAR (new_parent));
 	g_return_if_fail (MRP_IS_CALENDAR (child));
 
 	calendar_reparent (new_parent, child);
 
-	imrp_project_signal_calendar_tree_changed (new_parent->priv->project);
-	imrp_project_set_needs_saving (new_parent->priv->project, TRUE);
+	imrp_project_signal_calendar_tree_changed (priv->project);
+	imrp_project_set_needs_saving (priv->project, TRUE);
 }
 
 /**
@@ -522,7 +506,7 @@ mrp_calendar_reparent (MrpCalendar *new_parent, MrpCalendar *child)
 void
 mrp_calendar_remove (MrpCalendar *calendar)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	MrpCalendar     *parent;
 	MrpCalendar     *root;
 	GList          *list, *l;
@@ -531,7 +515,6 @@ mrp_calendar_remove (MrpCalendar *calendar)
 
 	g_return_if_fail (MRP_IS_CALENDAR (calendar));
 
-	priv   = calendar->priv;
 	parent = priv->parent;
 
 	root = mrp_project_get_root_calendar (priv->project);
@@ -595,21 +578,22 @@ mrp_calendar_remove (MrpCalendar *calendar)
 
 	for (l = list; l; l = l->next) {
 		MrpCalendar *child = l->data;
+		MrpCalendarPrivate *child_priv = mrp_calendar_get_instance_private (child);
 
 		if (parent) {
 			calendar_reparent (parent, child);
 		} else {
 			/* FIXME: Should never happen, right? */
 			g_warning ("No new parent.");
-			child->priv->parent = NULL;
+			child_priv->parent = NULL;
 		}
 	}
 
 	g_list_free (list);
 
 	if (parent) {
-		parent->priv->children = g_list_remove (parent->priv->children,
-							 calendar);
+		priv->children = g_list_remove (priv->children,
+						calendar);
 		priv->parent = NULL;
 	}
 
@@ -630,9 +614,11 @@ mrp_calendar_remove (MrpCalendar *calendar)
 const gchar *
 mrp_calendar_get_name (MrpCalendar *calendar)
 {
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
+
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), "");
 
-	return calendar->priv->name;
+	return priv->name;
 }
 
 /**
@@ -646,13 +632,11 @@ mrp_calendar_get_name (MrpCalendar *calendar)
 void
 mrp_calendar_set_name (MrpCalendar *calendar, const gchar *name)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 
 	g_return_if_fail (MRP_IS_CALENDAR (calendar));
 	g_return_if_fail (name != NULL);
 
-	priv = calendar->priv;
-
 	g_free (priv->name);
 	priv->name = g_strdup (name);
 }
@@ -671,13 +655,11 @@ mrp_calendar_day_set_intervals (MrpCalendar *calendar,
 				MrpDay      *day,
 				GList       *intervals)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	GList           *list;
 
 	g_return_if_fail (MRP_IS_CALENDAR (calendar));
 
-	priv = calendar->priv;
-
 	list = g_hash_table_lookup (priv->day_intervals, day);
 	if (list) {
 		g_list_foreach (list, (GFunc) mrp_interval_unref, NULL);
@@ -713,17 +695,15 @@ mrp_calendar_day_get_intervals (MrpCalendar *calendar,
 				MrpDay      *day,
 				gboolean     check_ancestors)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	GList          *list = NULL;
 
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), NULL);
 
-	priv = calendar->priv;
-
 	/* Look upwards in the tree structure until we find a calendar that has
 	 * defined the working time intervals for this day type.
 	 */
-	list = g_hash_table_lookup (calendar->priv->day_intervals, day);
+	list = g_hash_table_lookup (priv->day_intervals, day);
 
 	if (!list && check_ancestors && priv->parent) {
 		return mrp_calendar_day_get_intervals (priv->parent, day, TRUE);
@@ -778,12 +758,10 @@ MrpDay *
 mrp_calendar_get_default_day (MrpCalendar *calendar,
 			      gint         week_day)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), NULL);
 
-	priv = calendar->priv;
-
 	return priv->default_days[week_day];
 }
 
@@ -802,13 +780,11 @@ mrp_calendar_set_default_days (MrpCalendar *calendar,
 			       gint         week_day,
 			       ...)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	va_list          args;
 
 	g_return_if_fail (MRP_IS_CALENDAR (calendar));
 
-	priv = calendar->priv;
-
 	va_start (args, week_day);
 
 	/* Loop the args */
@@ -844,14 +820,13 @@ mrp_calendar_set_days (MrpCalendar *calendar,
 		       mrptime      date,
 		       ...)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	mrptime          time;
 	gint             key;
 	va_list          args;
 
 	g_return_if_fail (MRP_IS_CALENDAR (calendar));
 
-	priv = calendar->priv;
 	va_start (args, date);
 
 	for (time = date; time != -1; time = va_arg (args, mrptime)) {
@@ -890,16 +865,18 @@ mrp_calendar_set_days (MrpCalendar *calendar,
 MrpCalendar *
 mrp_calendar_get_parent (MrpCalendar *calendar)
 {
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
+
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), NULL);
 
-	return calendar->priv->parent;
+	return priv->parent;
 }
 
 /**
  * mrp_calendar_get_children:
  * @calendar: an #MrpCalendar
  *
- * Retreives a list of the children, i.e. the calenderas that are immediately
+ * Retrieves a list of the children, i.e. the calendars that are immediately
  * derived from @calendar.
  *
  * Return value: List of @calendar's children.
@@ -907,9 +884,11 @@ mrp_calendar_get_parent (MrpCalendar *calendar)
 GList *
 mrp_calendar_get_children (MrpCalendar *calendar)
 {
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
+
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), NULL);
 
-	return calendar->priv->children;
+	return priv->children;
 }
 
 /**
@@ -918,7 +897,7 @@ mrp_calendar_get_children (MrpCalendar *calendar)
  * @date: an #mrptime
  * @check_ancestors: specifies if the whole calendar hierarchy should be checked
  *
- * Retrieves the day type for the given date and calender. If @check_ancestors
+ * Retrieves the day type for the given date and calendar. If @check_ancestors
  * is %TRUE, the parent and grandparent, and so on, is searched if @calendar
  * does not have an overridden day type for the specified date.
  *
@@ -1098,7 +1077,7 @@ foreach_day_interval_add_to_list (MrpDay  *day,
  * @calendar: an #MrpCalendar
  *
  * Retrieves the days that are overridden in this calendar, and the intervals
- * that they are overriden with. This is mainly used when saving calendar data.
+ * that they are overridden with. This is mainly used when saving calendar data.
  *
  * Return value: A list of #MrpDayWithIntervals structs, that must be freed
  * (both the list and the data).
@@ -1106,13 +1085,11 @@ foreach_day_interval_add_to_list (MrpDay  *day,
 GList *
 mrp_calendar_get_overridden_days (MrpCalendar *calendar)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	GList           *ret_val = NULL;
 
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), NULL);
 
-	priv = calendar->priv;
-
 	g_hash_table_foreach (priv->day_intervals,
 			      (GHFunc) foreach_day_interval_add_to_list,
 			      &ret_val);
@@ -1143,13 +1120,11 @@ foreach_day_add_to_list (gpointer key, MrpDay *day, GList **list)
 GList *
 mrp_calendar_get_all_overridden_dates (MrpCalendar *calendar)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	GList           *ret_val = NULL;
 
 	g_return_val_if_fail (MRP_IS_CALENDAR (calendar), NULL);
 
-	priv = calendar->priv;
-
 	g_hash_table_foreach (priv->days,
 			      (GHFunc) foreach_day_add_to_list,
 			      &ret_val);
@@ -1177,7 +1152,7 @@ imrp_calendar_replace_day (MrpCalendar *calendar,
 			   MrpDay      *orig_day,
 			   MrpDay      *new_day)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	MatchingDayData  data;
 	GList          *l;
 	gint             i;
@@ -1186,8 +1161,6 @@ imrp_calendar_replace_day (MrpCalendar *calendar,
 	g_return_if_fail (orig_day != NULL);
 	g_return_if_fail (new_day != NULL);
 
-	priv = calendar->priv;
-
 	/* Default week. */
 	for (i = 0; i < 7; i++) {
 		if (priv->default_days[i] == orig_day) {
@@ -1218,11 +1191,9 @@ imrp_calendar_replace_day (MrpCalendar *calendar,
 static void
 calendar_emit_changed (MrpCalendar *calendar)
 {
-	MrpCalendarPriv *priv;
+	MrpCalendarPrivate *priv = mrp_calendar_get_instance_private (calendar);
 	GList          *l;
 
-	priv = calendar->priv;
-
 	g_signal_emit (calendar, signals[CALENDAR_CHANGED], 0, NULL);
 
 	for (l = priv->children; l; l = l->next) {
