@@ -18,8 +18,36 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
+
+/**
+ * SECTION:mrp-resource
+ * @Short_description: represents a resource in the project.
+ * @Title: MrpResource
+ * @include: libplanner/mrp-resource.h
+ *
+ * A resource has got a name.
+ *
+ * Resources come in #MrpResourceType: work, material.
+ *
+ * A resource has got a cost.
+ *
+ * A resource can belong to an #MrpGroup.
+ * An #MrpProject maintains a list of #MrpGroup and can designates one as the
+ * default. If you specify a default group, every new resource that you add
+ * will be placed in this group. Of course, you can still change the group to
+ * another as needed.
+ *
+ * A resource lists the assignments it is involved in.
+ * It knows about its assigned tasks.
+ *
+ * A resource can use its own #MrpCalendar instead of the project calendar.
+ *
+ * Resources are ordered.
+ *
+ * Administrative data can be associated: an email, a note.
  */
 
 #include <config.h>
@@ -32,8 +60,11 @@
 #include "mrp-task.h"
 #include "mrp-resource.h"
 
+struct _MrpResource {
+	MrpObject parent_instance;
+};
 
-struct _MrpResourcePriv {
+typedef struct {
 	gchar           *name;
 	gchar		*short_name;
         MrpGroup        *group;
@@ -45,7 +76,9 @@ struct _MrpResourcePriv {
 
 	MrpCalendar     *calendar;
 	gfloat           cost;
-};
+} MrpResourcePrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (MrpResource, mrp_resource, MRP_TYPE_OBJECT)
 
 /* Properties */
 enum {
@@ -69,189 +102,21 @@ enum {
 };
 
 
-static void resource_class_init            (MrpResourceClass *klass);
-static void resource_init                  (MrpResource      *resource);
-static void resource_finalize              (GObject          *object);
-static void resource_set_property          (GObject          *object,
-					    guint             prop_id,
-					    const GValue     *value,
-					    GParamSpec       *pspec);
-static void resource_get_property          (GObject          *object,
-					    guint             prop_id,
-					    GValue           *value,
-					    GParamSpec       *pspec);
 static void resource_calendar_changed      (MrpCalendar      *calendar,
 					    MrpResource      *resource);
-static void resource_removed               (MrpObject        *object);
 static void resource_invalidate_task_costs (MrpResource      *resource);
 static void resource_assignment_removed_cb (MrpAssignment    *assignment,
 					    MrpResource      *resource);
 static void resource_group_removed_cb      (MrpGroup         *group,
 					    MrpResource      *resource);
 
-
-static MrpObjectClass *parent_class;
 static guint signals[LAST_SIGNAL];
 
-
-GType
-mrp_resource_get_type (void)
-{
-	static GType object_type = 0;
-
-	if (!object_type) {
-		static const GTypeInfo object_info = {
-			sizeof (MrpResourceClass),
-			NULL,		/* base_init */
-			NULL,		/* base_finalize */
-			(GClassInitFunc) resource_class_init,
-			NULL,		/* class_finalize */
-			NULL,		/* class_data */
-			sizeof (MrpResource),
-			0,              /* n_preallocs */
-			(GInstanceInitFunc) resource_init,
-		};
-
-		object_type = g_type_register_static (MRP_TYPE_OBJECT,
-                                                      "MrpResource",
-                                                      &object_info, 0);
-	}
-
-	return object_type;
-}
-
 static void
-resource_class_init (MrpResourceClass *klass)
-{
-        GObjectClass   *object_class = G_OBJECT_CLASS (klass);
-        MrpObjectClass *mrp_object_class = MRP_OBJECT_CLASS (klass);
-
-        parent_class = MRP_OBJECT_CLASS (g_type_class_peek_parent (klass));
-
-        object_class->finalize     = resource_finalize;
-        object_class->set_property = resource_set_property;
-        object_class->get_property = resource_get_property;
-
-	mrp_object_class->removed  = resource_removed;
-
-	/* Properties */
-        g_object_class_install_property (object_class,
-                                         PROP_NAME,
-                                         g_param_spec_string ("name",
-                                                              "Name",
-                                                              "The name of the resource",
-                                                              NULL,
-                                                              G_PARAM_READWRITE));
-        g_object_class_install_property (object_class,
-                                         PROP_SHORT_NAME,
-                                         g_param_spec_string ("short_name",
-                                                              "Short name",
-                                                              "The shorter name, initials or nickname of the resource",
-                                                              NULL,
-                                                              G_PARAM_READWRITE));
-        g_object_class_install_property (object_class,
-                                         PROP_GROUP,
-                                         g_param_spec_object ("group",
-							      "Group",
-							      "The group that the resource belongs to",
-							      MRP_TYPE_GROUP,
-							      G_PARAM_READWRITE));
-        g_object_class_install_property (object_class,
-                                         PROP_TYPE,
-                                         g_param_spec_int ("type",
-                                                           "Type",
-                                                           "The type of resource this is",
-                                                           MRP_RESOURCE_TYPE_NONE,
-                                                           MRP_RESOURCE_TYPE_MATERIAL,
-                                                           MRP_RESOURCE_TYPE_WORK,
-                                                           G_PARAM_READWRITE));
-
-        g_object_class_install_property (object_class,
-                                         PROP_UNITS,
-                                         g_param_spec_int ("units",
-                                                           "Units",
-                                                           "The amount of units this resource has",
-                                                           -1,
-                                                           G_MAXINT,
-                                                           0,
-                                                           G_PARAM_READWRITE));
-
-        g_object_class_install_property (object_class,
-                                         PROP_EMAIL,
-                                         g_param_spec_string ("email",
-                                                              "Email",
-                                                              "The email address of the resource",
-                                                              NULL,
-                                                              G_PARAM_READWRITE));
-        g_object_class_install_property (object_class,
-                                         PROP_NOTE,
-                                         g_param_spec_string ("note",
-                                                              "Note",
-							      "Resource note",
-							      "",
-							      G_PARAM_READWRITE));
-	g_object_class_install_property (object_class,
-                                         PROP_CALENDAR,
-                                         g_param_spec_pointer ("calendar",
-							       "Calendar",
-							       "The calendar this resource uses",
-							       G_PARAM_READWRITE));
-        g_object_class_install_property (object_class,
-                                         PROP_COST,
-                                         g_param_spec_float ("cost",
-                                                             "Cost",
-                                                             "The standard cost of the resource",
-                                                             0.0,
-							     G_MAXFLOAT,
-                                                             0.0,
-                                                             G_PARAM_READWRITE));
-
-	/* Signals */
-	signals[ASSIGNMENT_ADDED] =
-		g_signal_new ("assignment_added",
-			      G_TYPE_FROM_CLASS (klass),
-			      G_SIGNAL_RUN_LAST,
-			      0,
-			      NULL, NULL,
-			      mrp_marshal_VOID__OBJECT,
-			      G_TYPE_NONE,
-			      1, MRP_TYPE_ASSIGNMENT);
-
-	signals[ASSIGNMENT_REMOVED] =
-		g_signal_new ("assignment_removed",
-			      G_TYPE_FROM_CLASS (klass),
-			      G_SIGNAL_RUN_LAST,
-			      0,
-			      NULL, NULL,
-			      mrp_marshal_VOID__OBJECT,
-			      G_TYPE_NONE,
-			      1, MRP_TYPE_ASSIGNMENT);
-}
-
-static void
-resource_init (MrpResource *resource)
-{
-        MrpResourcePriv *priv;
-
-        priv = g_new0 (MrpResourcePriv, 1);
-
-	priv->assignments = NULL;
-	priv->type        = MRP_RESOURCE_TYPE_NONE;
-        priv->name        = g_strdup ("");
-	priv->short_name    = g_strdup ("");
-	priv->group       = NULL;
-	priv->email       = g_strdup ("");
-	priv->note        = g_strdup ("");
-        resource->priv = priv;
-}
-
-static void
-resource_finalize (GObject *object)
+mrp_resource_finalize (GObject *object)
 {
         MrpResource     *resource = MRP_RESOURCE (object);
-        MrpResourcePriv *priv;
-
-        priv = resource->priv;
+	MrpResourcePrivate *priv = mrp_resource_get_instance_private (resource);
 
         g_free (priv->name);
 	g_free (priv->short_name);
@@ -264,22 +129,17 @@ resource_finalize (GObject *object)
 		g_object_unref (priv->calendar);
 	}
 
-	g_free (priv);
-	resource->priv = NULL;
-
-        if (G_OBJECT_CLASS (parent_class)->finalize) {
-                (* G_OBJECT_CLASS (parent_class)->finalize) (object);
-        }
+	G_OBJECT_CLASS (mrp_resource_parent_class)->finalize (object);
 }
 
 static void
-resource_set_property (GObject      *object,
-		       guint         prop_id,
-		       const GValue *value,
-		       GParamSpec   *pspec)
+mrp_resource_set_property (GObject      *object,
+                           guint         prop_id,
+                           const GValue *value,
+                           GParamSpec   *pspec)
 {
 	MrpResource     *resource;
-	MrpResourcePriv *priv;
+	MrpResourcePrivate *priv;
 	gboolean         changed = FALSE;
 	const gchar     *str;
 	gint             i_val;
@@ -289,7 +149,7 @@ resource_set_property (GObject      *object,
 	MrpProject      *project;
 
 	resource = MRP_RESOURCE (object);
-	priv     = resource->priv;
+	priv = mrp_resource_get_instance_private (resource);
 
 	switch (prop_id) {
 	case PROP_NAME:
@@ -423,16 +283,16 @@ resource_set_property (GObject      *object,
 }
 
 static void
-resource_get_property (GObject    *object,
-		       guint       prop_id,
-		       GValue     *value,
-		       GParamSpec *pspec)
+mrp_resource_get_property (GObject    *object,
+                           guint       prop_id,
+                           GValue     *value,
+                           GParamSpec *pspec)
 {
 	MrpResource     *resource;
-	MrpResourcePriv *priv;
+	MrpResourcePrivate *priv;
 
 	resource = MRP_RESOURCE (object);
-	priv     = resource->priv;
+	priv = mrp_resource_get_instance_private (resource);
 
 	switch (prop_id) {
 	case PROP_NAME:
@@ -468,21 +328,6 @@ resource_get_property (GObject    *object,
 	}
 }
 
-static void
-resource_calendar_changed (MrpCalendar *calendar,
-			   MrpResource *resource)
-{
-	MrpProject *project;
-
-	project = mrp_object_get_project (MRP_OBJECT (resource));
-
-	if (!project) {
-		return;
-	}
-
-	mrp_project_reschedule (project);
-}
-
 static void
 resource_remove_assignment_foreach (MrpAssignment *assignment,
 				    MrpResource   *resource)
@@ -499,24 +344,15 @@ resource_remove_assignment_foreach (MrpAssignment *assignment,
 }
 
 static void
-resource_invalidate_task_cost_foreach (MrpAssignment *assignment,
-				       MrpResource   *resource)
-{
-	g_return_if_fail (MRP_IS_ASSIGNMENT (assignment));
-
-	mrp_task_invalidate_cost (mrp_assignment_get_task (assignment));
-}
-
-static void
-resource_removed (MrpObject *object)
+mrp_resource_removed (MrpObject *object)
 {
 	MrpResource     *resource;
-	MrpResourcePriv *priv;
+	MrpResourcePrivate *priv;
 
 	g_return_if_fail (MRP_IS_RESOURCE (object));
 
 	resource = MRP_RESOURCE (object);
-	priv     = resource->priv;
+	priv = mrp_resource_get_instance_private (resource);
 
 	g_list_foreach (priv->assignments,
 			(GFunc) resource_remove_assignment_foreach,
@@ -525,9 +361,166 @@ resource_removed (MrpObject *object)
 	g_list_free (priv->assignments);
 	priv->assignments = NULL;
 
-        if (MRP_OBJECT_CLASS (parent_class)->removed) {
-                (* MRP_OBJECT_CLASS (parent_class)->removed) (object);
-        }
+	MRP_OBJECT_CLASS (mrp_resource_parent_class)->removed (object);
+}
+
+static void
+mrp_resource_class_init (MrpResourceClass *klass)
+{
+        GObjectClass   *object_class = G_OBJECT_CLASS (klass);
+	MrpObjectClass *mrp_object_class = MRP_OBJECT_CLASS (klass);
+
+        object_class->finalize     = mrp_resource_finalize;
+        object_class->set_property = mrp_resource_set_property;
+        object_class->get_property = mrp_resource_get_property;
+
+	mrp_object_class->removed  = mrp_resource_removed;
+
+	/* Properties */
+        g_object_class_install_property (object_class,
+                                         PROP_NAME,
+                                         g_param_spec_string ("name",
+                                                              "Name",
+                                                              "The name of the resource",
+                                                              NULL,
+                                                              G_PARAM_READWRITE));
+        g_object_class_install_property (object_class,
+                                         PROP_SHORT_NAME,
+                                         g_param_spec_string ("short_name",
+                                                              "Short name",
+                                                              "The shorter name, initials or nickname of the resource",
+                                                              NULL,
+                                                              G_PARAM_READWRITE));
+        g_object_class_install_property (object_class,
+                                         PROP_GROUP,
+                                         g_param_spec_object ("group",
+							      "Group",
+							      "The group that the resource belongs to",
+							      MRP_TYPE_GROUP,
+							      G_PARAM_READWRITE));
+        g_object_class_install_property (object_class,
+                                         PROP_TYPE,
+                                         g_param_spec_int ("type",
+                                                           "Type",
+                                                           "The type of resource this is",
+                                                           MRP_RESOURCE_TYPE_NONE,
+                                                           MRP_RESOURCE_TYPE_MATERIAL,
+                                                           MRP_RESOURCE_TYPE_WORK,
+                                                           G_PARAM_READWRITE));
+
+        g_object_class_install_property (object_class,
+                                         PROP_UNITS,
+                                         g_param_spec_int ("units",
+                                                           "Units",
+                                                           "The amount of units this resource has",
+                                                           -1,
+                                                           G_MAXINT,
+                                                           0,
+                                                           G_PARAM_READWRITE));
+
+        g_object_class_install_property (object_class,
+                                         PROP_EMAIL,
+                                         g_param_spec_string ("email",
+                                                              "Email",
+                                                              "The email address of the resource",
+                                                              NULL,
+                                                              G_PARAM_READWRITE));
+        g_object_class_install_property (object_class,
+                                         PROP_NOTE,
+                                         g_param_spec_string ("note",
+                                                              "Note",
+							      "Resource note",
+							      "",
+							      G_PARAM_READWRITE));
+	g_object_class_install_property (object_class,
+                                         PROP_CALENDAR,
+                                         g_param_spec_pointer ("calendar",
+							       "Calendar",
+							       "The calendar this resource uses",
+							       G_PARAM_READWRITE));
+        g_object_class_install_property (object_class,
+                                         PROP_COST,
+                                         g_param_spec_float ("cost",
+                                                             "Cost",
+                                                             "The standard cost of the resource",
+                                                             0.0,
+							     G_MAXFLOAT,
+                                                             0.0,
+                                                             G_PARAM_READWRITE));
+
+	/* Signals */
+
+    /**
+     * MrpResource::assignment-added:
+     * @resource: the object which received the signal.
+     * @assignment: the added #MrpAssignment.
+     *
+     * emitted when @assignment is added.
+     */
+	signals[ASSIGNMENT_ADDED] =
+		g_signal_new ("assignment_added",
+			      G_TYPE_FROM_CLASS (klass),
+			      G_SIGNAL_RUN_LAST,
+			      0,
+			      NULL, NULL,
+			      mrp_marshal_VOID__OBJECT,
+			      G_TYPE_NONE,
+			      1, MRP_TYPE_ASSIGNMENT);
+
+    /**
+     * MrpResource::assignment-removed:
+     * @resource: the object which received the signal.
+     * @assignment: the removed #MrpAssignment.
+     *
+     * emitted when @assignment is removed.
+     */
+	signals[ASSIGNMENT_REMOVED] =
+		g_signal_new ("assignment_removed",
+			      G_TYPE_FROM_CLASS (klass),
+			      G_SIGNAL_RUN_LAST,
+			      0,
+			      NULL, NULL,
+			      mrp_marshal_VOID__OBJECT,
+			      G_TYPE_NONE,
+			      1, MRP_TYPE_ASSIGNMENT);
+}
+
+static void
+mrp_resource_init (MrpResource *resource)
+{
+	MrpResourcePrivate *priv = mrp_resource_get_instance_private (resource);
+
+	priv->assignments = NULL;
+	priv->type        = MRP_RESOURCE_TYPE_NONE;
+        priv->name        = g_strdup ("");
+	priv->short_name    = g_strdup ("");
+	priv->group       = NULL;
+	priv->email       = g_strdup ("");
+	priv->note        = g_strdup ("");
+}
+
+static void
+resource_calendar_changed (MrpCalendar *calendar,
+			   MrpResource *resource)
+{
+	MrpProject *project;
+
+	project = mrp_object_get_project (MRP_OBJECT (resource));
+
+	if (!project) {
+		return;
+	}
+
+	mrp_project_reschedule (project);
+}
+
+static void
+resource_invalidate_task_cost_foreach (MrpAssignment *assignment,
+				       MrpResource   *resource)
+{
+	g_return_if_fail (MRP_IS_ASSIGNMENT (assignment));
+
+	mrp_task_invalidate_cost (mrp_assignment_get_task (assignment));
 }
 
 static void
@@ -544,14 +537,12 @@ static void
 resource_assignment_removed_cb (MrpAssignment *assignment,
 				MrpResource *resource)
 {
-	MrpResourcePriv *priv;
-	MrpTask         *task;
+	MrpResourcePrivate *priv = mrp_resource_get_instance_private (resource);
+	MrpTask            *task;
 
 	g_return_if_fail (MRP_IS_RESOURCE (resource));
 	g_return_if_fail (MRP_IS_ASSIGNMENT (assignment));
 
-	priv = resource->priv;
-
 	task = mrp_assignment_get_task (assignment);
 
 	if (!task) {
@@ -573,7 +564,8 @@ resource_assignment_removed_cb (MrpAssignment *assignment,
 static void
 resource_invalidate_task_costs (MrpResource *resource)
 {
-	g_list_foreach (resource->priv->assignments,
+	MrpResourcePrivate *priv = mrp_resource_get_instance_private (resource);
+	g_list_foreach (priv->assignments,
 			(GFunc) resource_invalidate_task_cost_foreach,
 			resource);
 }
@@ -590,13 +582,11 @@ resource_invalidate_task_costs (MrpResource *resource)
 void
 imrp_resource_add_assignment (MrpResource *resource, MrpAssignment *assignment)
 {
-	MrpResourcePriv *priv;
+	MrpResourcePrivate *priv = mrp_resource_get_instance_private (resource);
 
 	g_return_if_fail (MRP_IS_RESOURCE (resource));
 	g_return_if_fail (MRP_IS_ASSIGNMENT (assignment));
 
-	priv = resource->priv;
-
 	priv->assignments = g_list_prepend (priv->assignments,
 					    g_object_ref (assignment));
 
@@ -631,16 +621,18 @@ mrp_resource_new (void)
  * mrp_resource_get_name:
  * @resource: an #MrpResource
  *
- * Retrives the name of @resource.
+ * Retrieves the name of @resource.
  *
  * Return value: the name
  **/
 const gchar *
 mrp_resource_get_name (MrpResource *resource)
 {
+	MrpResourcePrivate *priv = mrp_resource_get_instance_private (resource);
+
 	g_return_val_if_fail (MRP_IS_RESOURCE (resource), NULL);
 
-	return resource->priv->name;
+	return priv->name;
 }
 
 /**
@@ -661,30 +653,32 @@ void mrp_resource_set_name (MrpResource *resource, const gchar *name)
  * mrp_resource_get_short_name:
  * @resource: an #MrpResource
  *
- * Retrives the short_name of @resource.
+ * Retrieves the short_name of @resource.
  *
  * Return value: the short name
  **/
 const gchar *
 mrp_resource_get_short_name (MrpResource *resource)
 {
+	MrpResourcePrivate *priv = mrp_resource_get_instance_private (resource);
+
 	g_return_val_if_fail (MRP_IS_RESOURCE (resource), NULL);
 
-	return resource->priv->short_name;
+	return priv->short_name;
 }
 
 /**
  * mrp_resource_set_short_name:
  * @resource: an #MrpResource
- * @name: new short name of @resource
+ * @short_name: new short name of @resource
  *
  * Sets the short name of @resource.
  **/
-void mrp_resource_set_short_name (MrpResource *resource, const gchar *name)
+void mrp_resource_set_short_name (MrpResource *resource, const gchar *short_name)
 {
 	g_return_if_fail (MRP_IS_RESOURCE (resource));
 
-	mrp_object_set (MRP_OBJECT (resource), "short_name", name, NULL);
+	mrp_object_set (MRP_OBJECT (resource), "short_name", short_name, NULL);
 }
 
 /**
@@ -731,9 +725,11 @@ mrp_resource_assign (MrpResource *resource,
 GList *
 mrp_resource_get_assignments (MrpResource *resource)
 {
+	MrpResourcePrivate *priv = mrp_resource_get_instance_private (resource);
+
 	g_return_val_if_fail (MRP_IS_RESOURCE (resource), NULL);
 
-	return resource->priv->assignments;
+	return priv->assignments;
 }
 
 /**
@@ -753,10 +749,11 @@ mrp_resource_get_assigned_tasks (MrpResource *resource)
 	GList         *l;
 	MrpAssignment *assignment;
 	MrpTask       *task;
+	MrpResourcePrivate *priv = mrp_resource_get_instance_private (resource);
 
 	g_return_val_if_fail (MRP_IS_RESOURCE (resource), NULL);
 
-	for (l = resource->priv->assignments; l; l = l->next) {
+	for (l = priv->assignments; l; l = l->next) {
 		assignment = l->data;
 		task       = mrp_assignment_get_task (assignment);
 
@@ -782,8 +779,10 @@ mrp_resource_get_assigned_tasks (MrpResource *resource)
 gint
 mrp_resource_compare (gconstpointer a, gconstpointer b)
 {
-	return strcmp (MRP_RESOURCE(a)->priv->name,
-		       MRP_RESOURCE(b)->priv->name);
+	MrpResourcePrivate *priv_a = mrp_resource_get_instance_private (MRP_RESOURCE ((gpointer)a));
+	MrpResourcePrivate *priv_b = mrp_resource_get_instance_private (MRP_RESOURCE ((gpointer)b));
+	return strcmp (priv_a->name,
+		       priv_b->name);
 }
 
 /**
@@ -798,12 +797,10 @@ mrp_resource_compare (gconstpointer a, gconstpointer b)
 MrpCalendar *
 mrp_resource_get_calendar (MrpResource *resource)
 {
-	MrpResourcePriv *priv;
+	MrpResourcePrivate *priv = mrp_resource_get_instance_private (resource);
 
 	g_return_val_if_fail (MRP_IS_RESOURCE (resource), NULL);
 
-	priv = resource->priv;
-
 	return priv->calendar;
 }
 
