@@ -27,13 +27,13 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <libgda/libgda.h>
+#include <libgda/sql-parser/gda-sql-parser.h>
 #include <libplanner/planner.h>
 #include <libplanner/mrp-private.h>
+#include <libplanner/mrp-relation.h>
 #include "mrp-storage-sql.h"
 #include "mrp-sql.h"
 
-#define d(x)
-
 #define REVISION "sql-storage-revision"
 
 #define CONNECTION_FORMAT_STRING "HOST=%s;DB_NAME=%s"
@@ -73,7 +73,6 @@ typedef struct {
 
 typedef struct {
 	GdaConnection *con;
-	GdaDict       *dict;
 
 	MrpProject    *project;
 	gint           project_id;
@@ -200,7 +199,7 @@ sql_quote_and_escape_const_string(SQLData     *data,
 	GValue         *value;
 	gchar          *quoted_string;
 
-	handler = gda_dict_get_handler(data->dict, G_TYPE_STRING);
+	handler = gda_data_handler_get_default(G_TYPE_STRING);
 	value = gda_data_handler_get_value_from_str(handler, string, G_TYPE_STRING);
 
 	quoted_string = gda_data_handler_get_sql_from_value(handler, value);
@@ -227,46 +226,56 @@ sql_quote_and_escape_string(SQLData   *data,
 	*string = quoted_string;
 }
 
+/*
+ * sql_execute_command:
+ * @cnc: an opened connection
+ * @sql: a query statement that must not begin with "SELECT"
+ *
+ * Execute a single non-SELECT SQL statement over an opened connection.
+ *
+ * src/planner-sql-plugin.c duplicates the code.
+ *
+ * Returns: %TRUE on success, %FALSE on failure.
+ *
+ * Deprecated: 0.14.6: Use gda_connection_execute_non_select_command() instead.
+ */
 static gboolean
-sql_execute_command (GdaConnection *con, gchar *command)
+sql_execute_command (GdaConnection *cnc, gchar *sql)
 {
-	GdaCommand *cmd;
-	GList      *list;
-	GError     *error = NULL;
-
-	cmd = gda_command_new (command, GDA_COMMAND_TYPE_SQL, GDA_COMMAND_OPTION_STOP_ON_ERRORS);
-	list = gda_connection_execute_command (con, cmd, NULL, &error);
-	gda_command_free (cmd);
-
-	while (list) {
-		if (list->data) {
-			g_object_unref (list->data);
-		}
-		list = list->next;
-	}
-	g_list_free (list);
-
-	if(error != NULL) {
-		g_error_free (error);
-		return FALSE;
-	}
-	else
-	{
-		return TRUE;
-	}
+    GError *error = NULL;
+    gda_connection_execute_non_select_command (cnc, sql, &error);
+    if (error) {
+        g_warning ("%s", error->message);
+        g_clear_error (&error);
+        return FALSE;
+    }
+    return TRUE;
 }
 
+/*
+ * sql_execute_query:
+ * @cnc: an opened connection
+ * @sql: a query statement that must begin with "SELECT"
+ *
+ * Execute an SQL SELECT command over an opened connection.
+ *
+ * src/planner-sql-plugin.c duplicates the code.
+ *
+ * Returns: (transfer full): a new #GdaDataModel if successful, %NULL otherwise
+ *
+ * Deprecated: 0.14.6: Use gda_connection_execute_select_command() instead.
+ */
 static GdaDataModel *
-sql_execute_query (GdaConnection *con, gchar *query)
+sql_execute_query (GdaConnection *cnc, gchar *sql)
 {
-	GdaCommand    *cmd;
-	GdaDataModel  *result;
-
-	cmd = gda_command_new (query, GDA_COMMAND_TYPE_SQL, GDA_COMMAND_OPTION_STOP_ON_ERRORS);
-	result = gda_connection_execute_select_command (con, cmd, NULL, NULL);
-	gda_command_free (cmd);
-
-	return result;
+    GdaDataModel *result;
+    GError *error = NULL;
+    result = gda_connection_execute_select_command (cnc, sql, &error);
+    if (error) {
+        g_warning ("%s", error->message);
+        g_clear_error (&error);
+    }
+    return result;
 }
 
 static const gchar *
@@ -299,11 +308,13 @@ get_int (GdaDataModel *model, gint row, gint column)
 	GValue   *value;
 	gchar    *str;
 	gint      i;
+	GError   *error = NULL;
 
-	value = (GValue *) gda_data_model_get_value_at (model, column, row);
+	value = (GValue *) gda_data_model_get_value_at (model, column, row, &error);
 	if (value == NULL) {
 		g_warning ("Failed to get a value: (%d,%d)", column, row);
-		d(sql_show_result (model));
+		g_warning ("%s", error->message);
+		g_clear_error (&error);
 		return INT_MAX;
 	}
 
@@ -319,11 +330,13 @@ get_id (GdaDataModel *model, gint row, gint column)
 	GValue   *value;
 	gchar    *str;
 	gint      i;
+	GError   *error = NULL;
 
-	value = (GValue *) gda_data_model_get_value_at (model, column, row);
+	value = (GValue *) gda_data_model_get_value_at (model, column, row, &error);
 	if (value == NULL) {
 		g_warning ("Failed to get a value: (%d,%d)", column, row);
-		d(sql_show_result (model));
+		g_warning ("%s", error->message);
+		g_clear_error (&error);
 		return INT_MAX;
 	}
 
@@ -346,11 +359,13 @@ get_string (GdaDataModel *model, gint row, gint column)
 	gsize     len;
 	gchar    *ret;
 	gchar    *str;
+	GError   *error = NULL;
 
-	value = (GValue *) gda_data_model_get_value_at (model, column, row);
+	value = (GValue *) gda_data_model_get_value_at (model, column, row, &error);
 	if (value == NULL) {
 		g_warning ("Failed to get a value: (%d,%d)", column, row);
-		d(sql_show_result (model));
+		g_warning ("%s", error->message);
+		g_clear_error (&error);
 		return g_strdup ("");
 	}
 
@@ -383,11 +398,13 @@ static gboolean
 get_boolean (GdaDataModel *model, gint row, gint column)
 {
 	GValue *value;
+	GError *error = NULL;
 
-	value = (GValue *) gda_data_model_get_value_at (model, column, row);
+	value = (GValue *) gda_data_model_get_value_at (model, column, row, &error);
 	if (value == NULL) {
 		g_warning ("Failed to get a value: (%d,%d)", column, row);
-		d(sql_show_result (model));
+		g_warning ("%s", error->message);
+		g_clear_error (&error);
 		return FALSE;
 	}
 
@@ -400,12 +417,14 @@ get_float (GdaDataModel *model, gint row, gint column)
 	GValue   *value;
 	gchar    *str;
 	gdouble   d;
+	GError   *error = NULL;
 
-	value = (GValue *) gda_data_model_get_value_at (model, column, row);
+	value = (GValue *) gda_data_model_get_value_at (model, column, row, &error);
 
 	if (value == NULL) {
 		g_warning ("Failed to get a value: (%d,%d)", column, row);
-		d(sql_show_result (model));
+		g_warning ("%s", error->message);
+		g_clear_error (&error);
 		return -1;
 	}
 
@@ -491,7 +510,7 @@ get_hash_data_as_id (GHashTable *hash, gpointer key)
 void
 mrp_sql_init (void)
 {
-	gda_init (PACKAGE, VERSION, 0, NULL);
+	gda_init ();
 }
 
 /*************************
@@ -844,7 +863,7 @@ sql_set_property_value (SQLData     *data,
 		mrp_object_set (object, name, i, NULL);
 		break;
 	case MRP_PROPERTY_TYPE_DATE:
-		date = mrp_time_from_string (value, NULL);
+		date = mrp_time_from_string (value);
 		mrp_object_set (object, name, &date, NULL);
 		break;
 	case MRP_PROPERTY_TYPE_COST:
@@ -1091,9 +1110,9 @@ sql_read_overriden_day_types (SQLData *data, gint calendar_id)
 		interval = mrp_interval_new (start, end);
 		day_type_data->intervals = g_list_append (day_type_data->intervals, interval);
 
-		d(g_print ("Overridden intervals for day %d, on cal %d, %d - %d\n",
+		g_debug ("Overridden intervals for day %d, on cal %d, %d - %d\n",
 			 day_type_id, calendar_id,
-			 (int)start, (int)end));
+			 (int)start, (int)end);
 	}
 	g_object_unref (model);
 	model = NULL;
@@ -1161,13 +1180,15 @@ sql_read_overriden_days (SQLData *data, gint calendar_id)
 		for (j = 0; j < n; j++) {
 			if (is_field (model, j, "date_seconds")) {
 				date = get_int (model, i, j);
+				g_debug ("model(%d, %d) is date_seconds(%ld)\n", i, j, date);
 			}
 			else if (is_field (model, j, "dtype_id")) {
 				day_type_id = get_int (model, i, j);
+				g_debug ("model(%d, %d) is dtype_id(%d)\n", i, j, day_type_id);
 			}
 		}
 
-		d(g_print ("Overridden for cal %d, on %s\n", calendar_id, mrp_time_format ("%a %e %b", date)));
+		g_debug ("Overridden for cal %d, on %s\n", calendar_id, mrp_time_format ("%a %e %b", date));
 
 		/*data->days = g_list_prepend (data->days, day);*/
 	}
@@ -1247,7 +1268,7 @@ sql_read_day_types (SQLData *data)
 			}
 		}
 
-		d(g_print ("Day type: %s, id: %d, work: %d, nonwork: %d\n", name, day_type_id, is_work, is_nonwork));
+		g_debug ("Day type: %s, id: %d, work: %d, nonwork: %d\n", name, day_type_id, is_work, is_nonwork);
 
 		if (is_work) {
 			day = mrp_day_get_work ();
@@ -1266,7 +1287,7 @@ sql_read_day_types (SQLData *data)
 	g_object_unref (model);
 	model = NULL;
 
-	sql_execute_query (data->con, "CLOSE mycursor");
+	sql_execute_command (data->con, "CLOSE mycursor");
 
 	return TRUE;
 
@@ -1294,11 +1315,11 @@ sql_calendar_create (GNode   *node,
 		/* Calendar directly under the root don't inherit from another
 		 * calendar.
 		 */
-		d(g_print ("Create new calendar: %s\n", cal_data->name));
+		g_debug ("Create new calendar: %s\n", cal_data->name);
 
 		calendar = mrp_calendar_new (cal_data->name, data->project);
 	} else {
-		d(g_print ("Derive new calendar: %s\n", cal_data->name));
+		g_debug ("Derive new calendar: %s\n", cal_data->name);
 
 		parent = g_hash_table_lookup (data->calendar_id_hash, GINT_TO_POINTER (cal_data->parent_id));
 		calendar = mrp_calendar_derive (cal_data->name, parent);
@@ -1367,7 +1388,7 @@ dump_calendar_tree (GNode *node)
 
 	data = node->data;
 
-	d(g_print ("%s%s\n", str, data ? data->name : "[Root]"));
+	g_debug ("%s%s\n", str, data ? data->name : "[Root]");
 	g_free (str);
 
 	for (child = node->children; child; child = child->next) {
@@ -1457,10 +1478,10 @@ sql_read_calendars (SQLData *data)
 			}
 		}
 
-		d(g_print ("Calendar: %s, id: %d, parent: %d\n",
+		g_debug ("Calendar: %s, id: %d, parent: %d\n",
 			 calendar_data->name,
 			 calendar_data->id,
-			 calendar_data->parent_id));
+			 calendar_data->parent_id);
 
 		calendars = g_list_prepend (calendars, node);
 		g_hash_table_insert (hash, GINT_TO_POINTER (calendar_data->id), node);
@@ -1588,7 +1609,7 @@ sql_read_groups (SQLData *data)
 	g_object_unref (model);
 	model = NULL;
 
-	sql_execute_query (data->con, "CLOSE mycursor");
+	sql_execute_command (data->con, "CLOSE mycursor");
 
 	return TRUE;
 
@@ -1872,7 +1893,7 @@ sql_read_relations (SQLData *data, gint task_id)
 	return FALSE;
 }
 
-/**
+/*
  * Insert a task from the GNode tree into the project.
  */
 static gboolean
@@ -1951,7 +1972,7 @@ dump_task_tree (GNode *node)
 	if (data) {
 		g_object_get (data->task, "name", &name, NULL);
 	}
-	d(g_print ("%s%s\n", str, data ? name : "[Root]"));
+	g_debug ("%s%s\n", str, data ? name : "[Root]");
 	g_free (name);
 	g_free (str);
 
@@ -2205,6 +2226,22 @@ sql_read_tasks (SQLData *data)
 	return FALSE;
 }
 
+/*
+ * mrp_sql_load_project:
+ * @storage: an #MrpStorageSQL
+ * @host: unused
+ * @port: unused
+ * @database: used to display warnings
+ * @login: unused
+ * @password: unused
+ * @project_id: identify the project in the database
+ * @error: location to store error, or NULL
+ *
+ * Import a project from a database.
+ * The "planner-auto" libgda DSN is used.
+ *
+ * Returns: %TRUE on success, %FALSE on failure.
+ */
 gboolean
 mrp_sql_load_project (MrpStorageSQL *storage,
 		      const gchar   *host,
@@ -2217,13 +2254,10 @@ mrp_sql_load_project (MrpStorageSQL *storage,
 {
 	SQLData        *data;
 	gboolean        success;
-	GdaClient      *client;
 	const gchar    *dsn_name = "planner-auto";
-	gchar          *db_txt;
 	MrpCalendar    *calendar;
 	MrpGroup       *group;
 	MrpTaskManager *task_manager;
-	const gchar    *provider = "PostgreSQL";
 
 	data = g_new0 (SQLData, 1);
 
@@ -2243,16 +2277,7 @@ mrp_sql_load_project (MrpStorageSQL *storage,
 
 	data->root_task = mrp_task_new ();
 
-	db_txt = g_strdup_printf (CONNECTION_FORMAT_STRING, host, database);
-	gda_config_save_data_source (dsn_name,
-				     provider,
-				     db_txt,
-				     "planner project", login, password, FALSE);
-	g_free (db_txt);
-
-	client = gda_client_new ();
-
-	data->con = gda_client_open_connection (client, dsn_name, NULL, NULL, 0, error);
+	data->con = gda_connection_open_from_dsn (dsn_name, NULL, GDA_CONNECTION_OPTIONS_NONE, error);
 
 	if (!GDA_IS_CONNECTION (data->con)) {
 		g_warning (_("Connection to database '%s' failed.\n"), database);
@@ -2266,14 +2291,6 @@ mrp_sql_load_project (MrpStorageSQL *storage,
 		goto out;
 	}
 
-	data->dict = gda_dict_new ();
-
-	if (!GDA_IS_DICT (data->dict)) {
-		g_warning (_("Failed to create a dictionary for the database connection.\n"));
-		goto out;
-	}
-	gda_dict_set_connection (data->dict, data->con);
-
 	success = sql_execute_command (data->con, "SET TIME ZONE 'UTC'");
 	if (!success) {
 		g_warning ("SET TIME ZONE command failed: %s.",
@@ -2347,7 +2364,7 @@ mrp_sql_load_project (MrpStorageSQL *storage,
 
 	g_object_unref (data->con);
 
-	d(g_print ("Read project, set rev to %d\n", data->revision));
+	g_debug ("Read project, set rev to %d\n", data->revision);
 
 	g_object_set_data (G_OBJECT (storage->project),
 			   REVISION,
@@ -2356,9 +2373,6 @@ mrp_sql_load_project (MrpStorageSQL *storage,
 	return TRUE;
 
  out:
-	if (data->dict) {
-		g_object_unref (data->dict);
-	}
 	if (data->con) {
 		g_object_unref (data->con);
 	}
@@ -2435,7 +2449,7 @@ sql_write_project (MrpStorageSQL  *storage,
 			sql_execute_command (data->con, "CLOSE mycursor");
 
 			/* Remove the old project. */
-			d(g_print ("Got old project with id %d (rev %d), remove.\n", project_id, revision));
+			g_debug ("Got old project with id %d (rev %d), remove.\n", project_id, revision);
 
 			query = g_strdup_printf ("DELETE FROM project WHERE proj_id=%d", project_id);
 			success = sql_execute_command (data->con, query);
@@ -2447,7 +2461,7 @@ sql_write_project (MrpStorageSQL  *storage,
 				goto out;
 			}
 
-			d(g_print ("*** revision: %d, old revision: %d\n", revision, data->revision));
+			g_debug ("*** revision: %d, old revision: %d\n", revision, data->revision);
 
 			if (!force && data->revision > 0 && revision != data->revision) {
 				g_set_error (error,
@@ -2494,12 +2508,12 @@ sql_write_project (MrpStorageSQL  *storage,
 	sql_quote_and_escape_string (data, &str, TRUE);
 
 	if (project_id != -1) {
-		d(g_print ("Trying to insert project with id: %d\n", project_id));
+		g_debug ("Trying to insert project with id: %d\n", project_id);
 		query = g_strdup_printf ("INSERT INTO project(proj_id, name, company, manager, proj_start, revision) "
 					 "VALUES(%d, %s, %s, %s, %s, %d)",
 					 project_id, name, company, manager, str, data->revision);
 	} else {
-		d(g_print ("Trying to insert new project.\n"));
+		g_debug ("Trying to insert new project.\n");
 		query = g_strdup_printf ("INSERT INTO project(name, company, manager, proj_start, revision) "
 					 "VALUES(%s, %s, %s, %s, %d)",
 					 name, company, manager, str, data->revision);
@@ -2520,7 +2534,7 @@ sql_write_project (MrpStorageSQL  *storage,
 		project_id = get_inserted_id (data, "project_proj_id_seq");
 	}
 
-	d(g_print ("Inserted project %s, %d\n", name, project_id));
+	g_debug ("Inserted project %s, %d\n", name, project_id);
 
 	data->project_id = project_id;
 
@@ -2730,7 +2744,7 @@ sql_write_specific_property_specs (SQLData *data, GList *properties, const gchar
 		}
 
 		id = get_inserted_id (data, "property_type_proptype_id_seq");
-		d(g_print ("Inserted property type '%s', %d\n", name, id));
+		g_debug ("Inserted property type '%s', %d\n", name, id);
 
 		g_hash_table_insert (data->property_type_hash, property, GINT_TO_POINTER (id));
 	}
@@ -2801,6 +2815,7 @@ sql_write_property_values (SQLData   *data,
 		label = mrp_property_get_label (property);
 		description = mrp_property_get_description (property);
 		type = property_type_to_string (mrp_property_get_property_type (property));
+		g_debug ("'%s', '%s', '%s'\n", label, description, type);
 
 		property_type_id = get_hash_data_as_id (data->property_type_hash, property);
 
@@ -2826,7 +2841,7 @@ sql_write_property_values (SQLData   *data,
 		}
 
 		id = get_inserted_id (data, "property_prop_id_seq");
-		d(g_print ("Inserted property '%s', %d\n", name, id));
+		g_debug ("Inserted property '%s', %d\n", name, id);
 
 		if (object_type == MRP_TYPE_PROJECT) {
 			str = "project_to_property(proj_id, prop_id)";
@@ -2926,7 +2941,7 @@ sql_write_day_types (SQLData *data)
 		}
 
 		id = get_inserted_id (data, "daytype_dtype_id_seq");
-		d(g_print ("Inserted day '%s', %d\n", mrp_day_get_name (day), id));
+		g_debug ("Inserted day '%s', %d\n", mrp_day_get_name (day), id);
 
 		g_hash_table_insert (data->day_hash, day, GINT_TO_POINTER (id));
 	}
@@ -3101,7 +3116,7 @@ sql_write_calendars_recurse (SQLData     *data,
 	}
 
 	id = get_inserted_id (data, "calendar_cal_id_seq");
-	d(g_print ("Inserted calendar %s, %d\n", name, id));
+	g_debug ("Inserted calendar %s, %d\n", name, id);
 
 	g_hash_table_insert (data->calendar_hash, calendar, GINT_TO_POINTER (id));
 
@@ -3235,7 +3250,7 @@ sql_write_groups (SQLData *data)
 		}
 
 		id = get_inserted_id (data, "resource_group_group_id_seq");
-		d(g_print ("Inserted group %s, %d\n", name, id));
+		g_debug ("Inserted group %s, %d\n", name, id);
 
 		g_hash_table_insert (data->group_hash, group, GINT_TO_POINTER (id));
 
@@ -3370,7 +3385,7 @@ sql_write_resources (SQLData *data)
 		}
 
 		id = get_inserted_id (data, "resource_res_id_seq");
-		d(g_print ("Inserted resource %s, %d\n", name, id));
+		g_debug ("Inserted resource %s, %d\n", name, id);
 
 		g_hash_table_insert (data->resource_hash, resource, GINT_TO_POINTER (id));
 
@@ -3540,7 +3555,7 @@ sql_write_tasks (SQLData *data)
 		}
 
 		id = get_inserted_id (data, "task_task_id_seq");
-		d(g_print ("Inserted task %s, %d under %d\n", name, id, parent_id));
+		g_debug ("Inserted task %s, %d under %d\n", name, id, parent_id);
 
 		g_hash_table_insert (data->task_hash, task, GINT_TO_POINTER (id));
 
@@ -3647,6 +3662,23 @@ sql_write_tasks (SQLData *data)
 	return FALSE;
 }
 
+/*
+ * mrp_sql_save_project:
+ * @storage: an #MrpStorageSQL
+ * @force: If the database changed since the import, overwrite the project or not?
+ * @host: unused
+ * @port: unused
+ * @database: used to display warnings
+ * @user: unused
+ * @password: unused
+ * @project_id: identify the project in the database
+ * @error: location to store error, or NULL
+ *
+ * Export a project to a database.
+ * The "planner-auto" libgda DSN is used.
+ *
+ * Returns: %TRUE on success, %FALSE on failure.
+ */
 gboolean
 mrp_sql_save_project (MrpStorageSQL  *storage,
 		      gboolean        force,
@@ -3659,12 +3691,9 @@ mrp_sql_save_project (MrpStorageSQL  *storage,
 		      GError        **error)
 {
 	SQLData      *data;
-	gchar        *db_txt = NULL;
 	const gchar  *dsn_name = "planner-auto";
 	gboolean      success;
-	GdaClient    *client;
 	gboolean      ret = FALSE;
-	const gchar  *provider = "PostgreSQL";
 
 	data = g_new0 (SQLData, 1);
 	data->project_id = *project_id;
@@ -3683,16 +3712,7 @@ mrp_sql_save_project (MrpStorageSQL  *storage,
 
 	data->project = storage->project;
 
-	db_txt = g_strdup_printf (CONNECTION_FORMAT_STRING, host, database);
-	gda_config_save_data_source (dsn_name,
-				     provider,
-				     db_txt,
-				     "planner project", user, password, FALSE);
-	g_free (db_txt);
-
-	client = gda_client_new ();
-
-	data->con = gda_client_open_connection (client, dsn_name, NULL, NULL, 0, error);
+	data->con = gda_connection_open_from_dsn (dsn_name, NULL, GDA_CONNECTION_OPTIONS_NONE, error);
 
 	data->revision = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (data->project),
 							     REVISION));
@@ -3705,14 +3725,6 @@ mrp_sql_save_project (MrpStorageSQL  *storage,
 		goto out;
 	}
 
-	data->dict = gda_dict_new ();
-
-	if (!GDA_IS_DICT (data->dict)) {
-		g_warning (_("Failed to create a dictionary for the database connection.\n"));
-		goto out;
-	}
-	gda_dict_set_connection (data->dict, data->con);
-
 	success = sql_execute_command (data->con, "SET TIME ZONE 'UTC'");
 
 	if (!success) {
@@ -3790,7 +3802,7 @@ mrp_sql_save_project (MrpStorageSQL  *storage,
 
 	sql_execute_command (data->con, "COMMIT");
 
-	d(g_print ("Write project, set rev to %d\n", data->revision));
+	g_debug ("Write project, set rev to %d\n", data->revision);
 
 	g_object_set_data (G_OBJECT (data->project), REVISION, GINT_TO_POINTER (data->revision));
 
