@@ -20,25 +20,20 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __MRP_STORAGE_SQL_H__
-#define __MRP_STORAGE_SQL_H__
+#pragma once
 
 #include <glib-object.h>
 #include "mrp-storage-module.h"
 #include "mrp-types.h"
 #include "mrp-project.h"
 
+G_BEGIN_DECLS
+
 extern GType mrp_storage_sql_type;
 
-#define MRP_TYPE_STORAGE_SQL		mrp_storage_sql_type
-#define MRP_STORAGE_SQL(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), MRP_TYPE_STORAGE_SQL, MrpStorageSQL))
-#define MRP_STORAGE_SQL_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), MRP_TYPE_STORAGE_SQL, MrpStorageSQLClass))
-#define MRP_IS_STORAGE_SQL(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), MRP_TYPE_STORAGE_SQL))
-#define MRP_IS_STORAGE_SQL_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((obj), MRP_TYPE_STORAGE_SQL))
-#define MRP_STORAGE_SQL_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), MRP_TYPE_STORAGE_SQL, MrpStorageSQLClass))
+#define MRP_TYPE_STORAGE_SQL		(mrp_storage_sql_get_type())
 
-typedef struct _MrpStorageSQL      MrpStorageSQL;
-typedef struct _MrpStorageSQLClass MrpStorageSQLClass;
+G_DECLARE_FINAL_TYPE (MrpStorageSQL, mrp_storage_sql, MRP, STORAGE_SQL, MrpStorageModule)
 
 struct _MrpStorageSQL {
 	MrpStorageModule  parent;
@@ -49,7 +44,4 @@ struct _MrpStorageSQLClass {
 	MrpStorageModuleClass parent_class;
 };
 
-
-void mrp_storage_sql_register_type (GTypeModule *module);
-
-#endif /* __MRP_STORAGE_SQL_H__ */
+G_END_DECLS
