@@ -18,22 +18,21 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
 #include <glib/gi18n.h>
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <libplanner/mrp-day.h>
 #include <libplanner/mrp-object.h>
 #include <libplanner/mrp-project.h>
 #include <libplanner/mrp-paths.h>
-#include "planner-calendar.h"
 #include "planner-working-time-dialog.h"
 #include "planner-default-week-dialog.h"
 #include "planner-calendar-dialog.h"
+#include "planner-util.h"
 
 
 #define RESPONSE_ADD          1
@@ -62,7 +61,7 @@ typedef struct {
 	GtkWidget     *name_label;
 
 	GtkWidget     *calendar;
-	GtkWidget     *option_menu;
+	GtkWidget     *daytype_combo;
 
 	GtkWidget     *base_radiobutton;
 	GtkWidget     *type_radiobutton;
@@ -88,10 +87,10 @@ typedef struct {
 #define DIALOG_GET_DATA(d) g_object_get_data ((GObject*)d, "data")
 
 
-static void          cal_dialog_setup_option_menu      (DialogData       *data);
-static void          cal_dialog_option_menu_set_day    (GtkWidget        *option_menu,
+static void          cal_dialog_setup_day_combo        (DialogData       *data);
+static void          cal_dialog_day_combo_set          (GtkWidget        *combo,
 							MrpDay           *day);
-static MrpDay *      cal_dialog_option_menu_get_day    (GtkWidget        *option_menu);
+static MrpDay *      cal_dialog_day_combo_get          (GtkWidget        *combo);
 static void          cal_dialog_response_cb            (GtkWidget        *dialog,
 							gint              response,
 							DialogData       *data);
@@ -107,11 +106,11 @@ static void          cal_dialog_selection_changed_cb   (GtkTreeSelection *select
 static void          cal_dialog_apply_clicked_cb       (GtkWidget        *button,
 							DialogData       *data);
 static void          cal_dialog_update_calendar_widgets (DialogData      *data);
-static void          cal_dialog_month_changed_cb       (PlannerCalendar       *calendar,
+static void          cal_dialog_month_changed_cb       (GtkCalendar      *calendar,
 							DialogData       *data);
-static void          cal_dialog_date_selected_cb       (PlannerCalendar       *calendar,
+static void          cal_dialog_date_selected_cb       (GtkCalendar      *calendar,
 							DialogData       *data);
-static void          cal_dialog_option_menu_changed_cb (GtkWidget        *option_menu,
+static void          cal_dialog_day_combo_changed_cb   (GtkWidget        *combo,
 							DialogData       *data);
 
 static void          cal_dialog_day_types_toggled_cb   (GtkWidget        *widget,
@@ -418,81 +417,70 @@ planner_cal_cmd_add (PlannerWindow  *main_window,
 }
 
 static void
-cal_dialog_setup_option_menu (DialogData *data)
+cal_dialog_setup_day_combo (DialogData *data)
 {
-	GtkOptionMenu *option_menu;
-	GList         *types, *l;
-	GtkWidget     *menu;
-	GtkWidget     *menu_item;
-	const gchar   *name;
-	MrpDay        *day;
+	GtkListStore *store;
+	GtkTreeIter   iter;
+	GList        *types, *l;
+
+	store = gtk_list_store_new (1, MRP_TYPE_DAY);
+	gtk_combo_box_set_model (GTK_COMBO_BOX (data->daytype_combo),
+				 GTK_TREE_MODEL (store));
+	g_object_unref (store);
+
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter,
+			    0, mrp_day_get_work (),
+			    -1);
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter,
+			    0, mrp_day_get_nonwork (),
+			    -1);
 
 	types = mrp_day_get_all (data->project);
 
-	types = g_list_prepend (types, mrp_day_get_nonwork ());
-	types = g_list_prepend (types, mrp_day_get_work ());
-
-	option_menu = GTK_OPTION_MENU (data->option_menu);
-	menu = gtk_option_menu_get_menu (option_menu);
-
-	if (menu) {
-		gtk_widget_destroy (menu);
-	}
-
-	menu = gtk_menu_new ();
-
 	for (l = types; l; l = l->next) {
-		day = l->data;
-
-		name = mrp_day_get_name (day);
-
-		menu_item = gtk_menu_item_new_with_label (name);
-		gtk_widget_show (menu_item);
-		gtk_menu_append (GTK_MENU (menu), menu_item);
-
-		g_object_set_data (G_OBJECT (menu_item),
-				   "data",
-				   day);
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+				    0, MRP_DAY (l->data),
+				    -1);
 	}
 
-	gtk_widget_show (menu);
-	gtk_option_menu_set_menu (option_menu, menu);
-
 	g_list_free (types);
 }
 
 static void
-cal_dialog_option_menu_set_day (GtkWidget *option_menu,
-				MrpDay    *day)
+cal_dialog_day_combo_set (GtkWidget *combo,
+			  MrpDay    *day)
 {
-	GtkWidget *menu;
-	GtkWidget *item;
-	GList     *children, *l;
-	gint       i;
+	GtkTreeModel *model;
+	GtkTreeIter   iter;
+	MrpDay       *iter_day;
 
-       	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+	gtk_tree_model_get_iter_first (model, &iter);
 
-	children = GTK_MENU_SHELL (menu)->children;
-	for (i = 0, l = children; l; i++, l = l->next) {
-		item = l->data;
-
-		if (day == g_object_get_data (G_OBJECT (item), "data")) {
-			gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), i);
-			break;
+	do {
+		gtk_tree_model_get (model, &iter, 0, &iter_day, -1);
+		if (iter_day == day) {
+			gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo), &iter);
+			return;
 		}
-	}
+	} while (gtk_tree_model_iter_next (model, &iter));
 }
 
 static MrpDay *
-cal_dialog_option_menu_get_day (GtkWidget *option_menu)
+cal_dialog_day_combo_get (GtkWidget *combo)
 {
-	GtkWidget *menu;
-	GtkWidget *item;
+	GtkTreeIter  iter;
+	MrpDay      *day;
 
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-	item = gtk_menu_get_active (GTK_MENU (menu));
-
-	return g_object_get_data (G_OBJECT (item), "data");
+	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter);
+	gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (combo)),
+			    &iter,
+			    0, &day,
+			    -1);
+	return day;
 }
 
 static void
@@ -579,32 +567,34 @@ cal_dialog_parent_destroy_cb (GtkWidget *window, GtkWidget *dialog)
 	gtk_widget_destroy (dialog);
 }
 
+static void
+daytype_combo_get_name (GtkCellLayout   *layout,
+                        GtkCellRenderer *cell,
+                        GtkTreeModel    *model,
+                        GtkTreeIter     *iter,
+                        gpointer         user_data)
+{
+	MrpDay *day;
+	gtk_tree_model_get (model, iter, 0, &day, -1);
+	g_object_set (cell, "text", mrp_day_get_name (day), NULL);
+}
+
 GtkWidget *
 planner_calendar_dialog_new (PlannerWindow *window)
 {
 	DialogData       *data;
-	GladeXML         *glade;
+	GtkBuilder       *builder;
 	GtkWidget        *dialog;
 	GtkWidget        *w;
 	GtkTreeSelection *selection;
 	gint              i;
-	gchar		*filename;
+	GtkCellRenderer  *renderer;
 
 	g_return_val_if_fail (PLANNER_IS_WINDOW (window), NULL);
 
-	filename = mrp_paths_get_glade_dir ("calendar-dialog.glade");
-	glade = glade_xml_new (filename ,
-			       "calendar_dialog",
-			       GETTEXT_PACKAGE);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/ui/calendar-dialog.ui");
 
-	g_free (filename);
-
-	if (!glade) {
-		g_warning ("Could not create calendar dialog.");
-		return NULL;
-	}
-
-	dialog = glade_xml_get_widget (glade, "calendar_dialog");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "calendar_dialog"));
 
 	data = g_new0 (DialogData, 1);
 
@@ -618,15 +608,14 @@ planner_calendar_dialog_new (PlannerWindow *window)
 				 dialog,
 				 0);
 
-	data->tree_view = glade_xml_get_widget (glade, "treeview");
-	data->calendar = planner_calendar_new ();
+	data->tree_view = GTK_WIDGET (gtk_builder_get_object (builder, "treeview"));
+	data->calendar = gtk_calendar_new ();
 	gtk_widget_show (data->calendar);
 
-	planner_calendar_display_options (PLANNER_CALENDAR (data->calendar),
-					  PLANNER_CALENDAR_SHOW_HEADING |
-					  PLANNER_CALENDAR_SHOW_DAY_NAMES |
-					  PLANNER_CALENDAR_SHOW_WEEK_NUMBERS |
-					  PLANNER_CALENDAR_WEEK_START_MONDAY);
+	gtk_calendar_set_display_options (GTK_CALENDAR (data->calendar),
+					  GTK_CALENDAR_SHOW_HEADING |
+					  GTK_CALENDAR_SHOW_DAY_NAMES |
+					  GTK_CALENDAR_SHOW_WEEK_NUMBERS);
 	g_signal_connect (data->calendar,
 			  "month_changed",
 			  G_CALLBACK (cal_dialog_month_changed_cb),
@@ -637,53 +626,60 @@ planner_calendar_dialog_new (PlannerWindow *window)
 			  G_CALLBACK (cal_dialog_date_selected_cb),
 			  data);
 
-	w = glade_xml_get_widget (glade, "calendar_frame");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "calendar_frame"));
 	gtk_container_add (GTK_CONTAINER (w), data->calendar);
 
-	data->remove_button = glade_xml_get_widget (glade, "remove_button");
-	data->apply_button = glade_xml_get_widget (glade, "apply_button");
+	data->remove_button = GTK_WIDGET (gtk_builder_get_object (builder, "remove_button"));
+	data->apply_button = GTK_WIDGET (gtk_builder_get_object (builder, "apply_button"));
 
 	g_signal_connect  (data->apply_button,
 			   "clicked",
 			   G_CALLBACK (cal_dialog_apply_clicked_cb),
 			   data);
 
-	data->default_week_button = glade_xml_get_widget (glade, "default_week_button");
-	data->working_time_button = glade_xml_get_widget (glade, "working_time_button");
+	data->default_week_button = GTK_WIDGET (gtk_builder_get_object (builder, "default_week_button"));
+	data->working_time_button = GTK_WIDGET (gtk_builder_get_object (builder, "working_time_button"));
 
 	/* Get the 5 from/to entries. */
 	for (i = 0; i < 5; i++) {
 		gchar *tmp;
 
 		tmp = g_strdup_printf ("from%d_entry", i + 1);
-		data->from_entry[i] = glade_xml_get_widget (glade, tmp);
+		data->from_entry[i] = GTK_WIDGET (gtk_builder_get_object (builder, tmp));
 		g_free (tmp);
 
 		tmp = g_strdup_printf ("to%d_entry", i + 1);
-		data->to_entry[i] = glade_xml_get_widget (glade, tmp);
+		data->to_entry[i] = GTK_WIDGET (gtk_builder_get_object (builder, tmp));
 		g_free (tmp);
 	}
 
-	data->option_menu = glade_xml_get_widget (glade, "optionmenu");
-	cal_dialog_setup_option_menu (data);
-	g_signal_connect  (data->option_menu,
-			   "changed",
-			   G_CALLBACK (cal_dialog_option_menu_changed_cb),
-			   data);
+	data->daytype_combo = GTK_WIDGET (gtk_builder_get_object (builder, "combo_daytype"));
+	cal_dialog_setup_day_combo (data);
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (data->daytype_combo),
+				    renderer, TRUE);
+	gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (data->daytype_combo),
+					    renderer,
+					    daytype_combo_get_name,
+					    NULL, NULL);
+	g_signal_connect (data->daytype_combo,
+			  "changed",
+			  G_CALLBACK (cal_dialog_day_combo_changed_cb),
+			  data);
 
-	data->base_radiobutton = glade_xml_get_widget (glade, "base_radiobutton");
+	data->base_radiobutton = GTK_WIDGET (gtk_builder_get_object (builder, "base_radiobutton"));
 	g_signal_connect (data->base_radiobutton,
 			  "toggled",
 			  G_CALLBACK (cal_dialog_day_types_toggled_cb),
 			  data);
 
-	data->type_radiobutton = glade_xml_get_widget (glade, "type_radiobutton");
+	data->type_radiobutton = GTK_WIDGET (gtk_builder_get_object (builder, "type_radiobutton"));
 	g_signal_connect (data->type_radiobutton,
 			  "toggled",
 			  G_CALLBACK (cal_dialog_day_types_toggled_cb),
 			  data);
 
-	data->custom_radiobutton = glade_xml_get_widget (glade, "custom_radiobutton");
+	data->custom_radiobutton = GTK_WIDGET (gtk_builder_get_object (builder, "custom_radiobutton"));
 	g_signal_connect (data->custom_radiobutton,
 			  "toggled",
 			  G_CALLBACK (cal_dialog_day_types_toggled_cb),
@@ -731,6 +727,7 @@ planner_calendar_dialog_new (PlannerWindow *window)
 			  G_CALLBACK (cal_dialog_destroy_cb),
 			  data);
 
+	g_object_unref (builder);
 	return dialog;
 }
 
@@ -835,14 +832,14 @@ cal_dialog_apply_clicked_cb (GtkWidget  *button,
 	}
 	else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->type_radiobutton))) {
 		/* Day type. */
-		day = cal_dialog_option_menu_get_day (data->option_menu);
+		day = cal_dialog_day_combo_get (data->daytype_combo);
 	} else {
 		/* Custom. Not implemented yet. */
 		day = NULL;
 		return;
 	}
 
-	planner_calendar_get_date (PLANNER_CALENDAR (data->calendar), &y, &m, &d);
+	gtk_calendar_get_date (GTK_CALENDAR (data->calendar), &y, &m, &d);
 	t = mrp_time_compose (y, m + 1, d, 0, 0, 0);
 	/* mrp_calendar_set_days (calendar, t, day, (mrptime) -1); */
 	planner_cal_cmd_day_type (data->main_window, calendar, day, t);
@@ -859,6 +856,7 @@ cal_dialog_setup_tree_view (GtkTreeView *tree_view,
 	model = cal_dialog_create_model (project, tree_view);
 
 	gtk_tree_view_set_model (tree_view, model);
+	g_object_unref (model);
 
 	cell = gtk_cell_renderer_text_new ();
 	col = gtk_tree_view_column_new_with_attributes (
@@ -875,11 +873,11 @@ static void
 cal_dialog_update_calendar_widgets (DialogData *data)
 {
 	MrpCalendar *calendar;
-	PlannerCalendar  *calendar_widget;
+	GtkCalendar *calendar_widget;
 	guint        y, m, d;
 	MrpDay      *day;
-	MrpTime      *t;
 	mrptime      time;
+	GDateTime   *dt;
 
 	calendar = cal_dialog_get_selected_calendar (GTK_TREE_VIEW (data->tree_view));
 	if (!calendar) {
@@ -889,41 +887,33 @@ cal_dialog_update_calendar_widgets (DialogData *data)
 		return;
 	}
 
-	calendar_widget = PLANNER_CALENDAR (data->calendar);
+	calendar_widget = GTK_CALENDAR (data->calendar);
 
 	gtk_widget_set_sensitive (data->calendar, TRUE);
 	gtk_widget_set_sensitive (data->default_week_button, TRUE);
 	gtk_widget_set_sensitive (data->working_time_button, TRUE);
 
-	planner_calendar_get_date (calendar_widget, &y, &m, &d);
+	gtk_calendar_get_date (calendar_widget, &y, &m, &d);
 
-	t = mrp_time2_new ();
-	mrp_time2_set_date (t, y, m+1, 1);
-	mrp_time2_set_time (t, 0, 0, 0);
-
-	for (d = 1; d <= 31; d++) {
-		time = mrp_time2_get_epoch (t);
+	d = 0;
+	while ((dt = g_date_time_new_utc (y, m+1, ++d, 0, 0, 0.0)) != NULL) {
+		time = g_date_time_to_unix (dt);
 
 		day = mrp_calendar_get_day (calendar, time, TRUE);
 
 		if (day == mrp_day_get_nonwork ()) {
-			planner_calendar_mark_day (calendar_widget,
-						   d,
-						   PLANNER_CALENDAR_MARK_SHADE);
+			gtk_calendar_mark_day (calendar_widget, d);
 		}
 		else if (day == mrp_day_get_work ()) {
-			planner_calendar_mark_day (calendar_widget,
-						   d,
-						   PLANNER_CALENDAR_MARK_NONE);
+			gtk_calendar_unmark_day (calendar_widget, d);
 		}
 
-		mrp_time2_add_days (t, 1);
-	}
-	mrp_time2_free (t);
+		g_date_time_unref (dt);
+	};
 }
 
 static void
-cal_dialog_month_changed_cb (PlannerCalendar *calendar_widget,
+cal_dialog_month_changed_cb (GtkCalendar *calendar_widget,
 			     DialogData *data)
 {
 	cal_dialog_update_calendar_widgets (data);
@@ -931,15 +921,15 @@ cal_dialog_month_changed_cb (PlannerCalendar *calendar_widget,
 }
 
 static void
-cal_dialog_date_selected_cb (PlannerCalendar *calendar_widget,
+cal_dialog_date_selected_cb (GtkCalendar *calendar_widget,
 			     DialogData *data)
 {
 	cal_dialog_update_day_widgets (data);
 }
 
 static void
-cal_dialog_option_menu_changed_cb (GtkWidget  *option_menu,
-				   DialogData *data)
+cal_dialog_day_combo_changed_cb (GtkWidget  *combo,
+				 DialogData *data)
 {
 	gtk_widget_set_sensitive (data->apply_button, TRUE);
 }
@@ -952,7 +942,7 @@ cal_dialog_day_types_toggled_cb (GtkWidget  *widget,
 	gint     i;
 
 	sensitive = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data->type_radiobutton));
-	gtk_widget_set_sensitive (data->option_menu, sensitive);
+	gtk_widget_set_sensitive (data->daytype_combo, sensitive);
 
 	gtk_widget_set_sensitive (data->apply_button, TRUE);
 
@@ -970,7 +960,7 @@ cal_dialog_update_day_widgets (DialogData *data)
 	MrpDay      *day;
 	GList       *ivals, *l;
 	MrpCalendar *calendar, *root;
-	PlannerCalendar  *calendar_widget;
+	GtkCalendar *calendar_widget;
 	guint        y, m, d;
 	mrptime      t;
 	gint         i;
@@ -985,7 +975,7 @@ cal_dialog_update_day_widgets (DialogData *data)
 	if (!calendar) {
 		gtk_widget_set_sensitive (data->base_radiobutton, FALSE);
 		gtk_widget_set_sensitive (data->type_radiobutton, FALSE);
-		gtk_widget_set_sensitive (data->option_menu, FALSE);
+		gtk_widget_set_sensitive (data->daytype_combo, FALSE);
 		gtk_widget_set_sensitive (data->custom_radiobutton, FALSE);
 
 		return;
@@ -993,8 +983,8 @@ cal_dialog_update_day_widgets (DialogData *data)
 
 	gtk_widget_set_sensitive (data->type_radiobutton, TRUE);
 
-	g_signal_handlers_block_by_func (data->option_menu,
-					 cal_dialog_option_menu_changed_cb,
+	g_signal_handlers_block_by_func (data->daytype_combo,
+					 cal_dialog_day_combo_changed_cb,
 					 data);
 	g_signal_handlers_block_by_func (data->base_radiobutton,
 					 cal_dialog_day_types_toggled_cb,
@@ -1014,22 +1004,22 @@ cal_dialog_update_day_widgets (DialogData *data)
 		gtk_widget_set_sensitive (data->base_radiobutton, TRUE);
 	}
 
-	calendar_widget = PLANNER_CALENDAR (data->calendar);
+	calendar_widget = GTK_CALENDAR (data->calendar);
 
-	planner_calendar_get_date (calendar_widget, &y, &m, &d);
+	gtk_calendar_get_date (calendar_widget, &y, &m, &d);
 	t = mrp_time_compose (y, m + 1, d, 0, 0, 0);
 
 	day = mrp_calendar_get_day (calendar, t, FALSE);
 
 	if (day == mrp_day_get_use_base ()) {
-		gtk_widget_set_sensitive (data->option_menu, FALSE);
+		gtk_widget_set_sensitive (data->daytype_combo, FALSE);
 
 		gtk_toggle_button_set_active (
 			GTK_TOGGLE_BUTTON (data->base_radiobutton), TRUE);
 	} else {
-		gtk_widget_set_sensitive (data->option_menu, TRUE);
+		gtk_widget_set_sensitive (data->daytype_combo, TRUE);
 
-		cal_dialog_option_menu_set_day (data->option_menu, day);
+		cal_dialog_day_combo_set (data->daytype_combo, day);
 
 		gtk_toggle_button_set_active (
 			GTK_TOGGLE_BUTTON (data->type_radiobutton), TRUE);
@@ -1066,8 +1056,8 @@ cal_dialog_update_day_widgets (DialogData *data)
 		g_free (str);
 	}
 
-	g_signal_handlers_unblock_by_func (data->option_menu,
-					   cal_dialog_option_menu_changed_cb,
+	g_signal_handlers_unblock_by_func (data->daytype_combo,
+					   cal_dialog_day_combo_changed_cb,
 					   data);
 	g_signal_handlers_unblock_by_func (data->base_radiobutton,
 					   cal_dialog_day_types_toggled_cb,
@@ -1087,12 +1077,12 @@ cal_dialog_project_day_added_cb (MrpProject *project,
 {
 	MrpDay *selected_day;
 
-	selected_day = cal_dialog_option_menu_get_day (data->option_menu);
+	selected_day = cal_dialog_day_combo_get (data->daytype_combo);
 
-	cal_dialog_setup_option_menu (data);
+	cal_dialog_setup_day_combo (data);
 
 	/* Reselect the same day as before. */
-	cal_dialog_option_menu_set_day (data->option_menu, selected_day);
+	cal_dialog_day_combo_set (data->daytype_combo, selected_day);
 }
 
 static void
@@ -1100,31 +1090,26 @@ cal_dialog_project_day_removed_cb (MrpProject *project,
 				   MrpDay     *day,
 				   DialogData *data)
 {
-	GtkOptionMenu *option_menu;
-	GtkWidget     *menu;
-	GtkWidget     *item;
-	GList         *children, *l;
+	GtkTreeModel *model;
+	GtkTreeIter   iter;
+	MrpDay       *iter_day;
 
 	/* We get the signal before the day is actually removed, so we can't
 	 * just re-add all types, we need to find it and remove it.
 	 */
+	/* TODO: Can't we adjust the signal to be RUN_FIRST and then
+	 * connect_after? */
 
-	option_menu = GTK_OPTION_MENU (data->option_menu);
-	menu = gtk_option_menu_get_menu (option_menu);
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (data->daytype_combo));
+	gtk_tree_model_get_iter_first (model, &iter);
 
-	if (!menu) {
-		return;
-	}
-
-	children = GTK_MENU_SHELL (menu)->children;
-	for (l = children; l; l = l->next) {
-		item = l->data;
-
-		if (day == g_object_get_data (G_OBJECT (item), "data")) {
-			gtk_widget_destroy (item);
-			break;
+	do {
+		gtk_tree_model_get (model, &iter, 0, &iter_day, -1);
+		if (iter_day == day) {
+			gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+			return;
 		}
-	}
+	} while (gtk_tree_model_iter_next (model, &iter));
 }
 
 static void
@@ -1252,7 +1237,7 @@ cal_dialog_new_name_changed_cb (GtkEntry   *entry,
 static void
 cal_dialog_new_dialog_run (DialogData *data)
 {
-	GladeXML         *glade;
+	GtkBuilder       *builder;
 	GtkWidget        *dialog;
 	MrpCalendar      *parent;
 	GtkTreeSelection *selection;
@@ -1260,29 +1245,24 @@ cal_dialog_new_dialog_run (DialogData *data)
 	GtkWidget        *tree_view;
 	const gchar      *name;
 	GtkTreePath      *path;
-	gchar            *filename;
 
-	filename = mrp_paths_get_glade_dir ("calendar-dialog.glade");
-	glade = glade_xml_new (filename,
-			       "new_calendar_dialog",
-			       GETTEXT_PACKAGE);
-	g_free (filename);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/ui/new-calendar-dialog.ui");
 
-	dialog = glade_xml_get_widget (glade, "new_calendar_dialog");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "new_calendar_dialog"));
 
-	data->new_ok_button = glade_xml_get_widget (glade, "ok_button");
+	data->new_ok_button = GTK_WIDGET (gtk_builder_get_object (builder, "ok_button"));
 
-	entry = glade_xml_get_widget (glade, "name_entry");
+	entry = GTK_WIDGET (gtk_builder_get_object (builder, "name_entry"));
 	g_signal_connect (entry,
 			  "changed",
 			  G_CALLBACK (cal_dialog_new_name_changed_cb),
 			  data);
 
-	data->new_copy_radiobutton = glade_xml_get_widget (glade, "copy_radiobutton");
-	data->new_derive_radiobutton = glade_xml_get_widget (glade, "derive_radiobutton");
-	data->new_empty_radiobutton = glade_xml_get_widget (glade, "empty_radiobutton");
+	data->new_copy_radiobutton = GTK_WIDGET (gtk_builder_get_object (builder, "copy_radiobutton"));
+	data->new_derive_radiobutton = GTK_WIDGET (gtk_builder_get_object (builder, "derive_radiobutton"));
+	data->new_empty_radiobutton = GTK_WIDGET (gtk_builder_get_object (builder, "empty_radiobutton"));
 
-	tree_view = glade_xml_get_widget (glade, "treeview");
+	tree_view = GTK_WIDGET (gtk_builder_get_object (builder, "treeview"));
 	cal_dialog_setup_tree_view (GTK_TREE_VIEW (tree_view), data->project);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
@@ -1326,6 +1306,6 @@ cal_dialog_new_dialog_run (DialogData *data)
 		}
 	}
 
-	g_object_unref (glade);
+	g_object_unref (builder);
 	gtk_widget_destroy (dialog);
 }
