@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -30,6 +30,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <libplanner/mrp-task.h>
+#include <libplanner/mrp-relation.h>
 #include "planner-marshal.h"
 #include "planner-conf.h"
 #include "planner-gantt-chart.h"
@@ -47,15 +48,15 @@
 #define ZOOM_OUT_LIMIT 0
 
 #define DEFAULT_ZOOM_LEVEL 7
-#define SCALE(n) (f*pow(2,(n)-19))
-#define ZOOM(x) (log((x)/f)/log(2)+19)
+#define SCALE(n) (font_width_factor*pow(2,(n)-19))
+#define ZOOM(x) (log((x)/font_width_factor)/log(2)+19)
 
 /* Font width factor. */
-static gdouble f = 1.0;
+static gdouble font_width_factor = 1.0;
 
-#define CRITICAL_PATH_KEY  "/views/gantt_view/highlight_critical_path"
-#define NOSTDDAYS_PATH_KEY "/views/gantt_view/display_nonstandard_days"
-#define GUIDELINES_PATH_KEY "/views/gantt_view/show_guidelines"
+#define CRITICAL_PATH_KEY  "highlight-critical-path"
+#define NOSTDDAYS_PATH_KEY "display-nonstandard-days"
+#define GUIDELINES_PATH_KEY "show-guidelines"
 
 
 typedef struct _TreeNode TreeNode;
@@ -81,6 +82,8 @@ struct _PlannerGanttChartPriv {
 
 	GtkAdjustment   *hadjustment;
 	GtkAdjustment   *vadjustment;
+	guint            hscroll_policy : 1;
+	guint            vscroll_policy : 1;
 
 	GtkTreeModel    *model;
 	TreeNode        *tree;
@@ -123,7 +126,12 @@ enum {
 	PROP_0,
 	PROP_HEADER_HEIGHT,
 	PROP_ROW_HEIGHT,
-	PROP_MODEL
+	PROP_MODEL,
+	/* Scrollable interface */
+	PROP_HADJUSTMENT,
+	PROP_VADJUSTMENT,
+	PROP_HSCROLL_POLICY,
+	PROP_VSCROLL_POLICY
 };
 
 enum {
@@ -143,16 +151,16 @@ static void        gantt_chart_get_property             (GObject            *obj
 							 guint               prop_id,
 							 GValue             *value,
 							 GParamSpec         *pspec);
-static void        gantt_chart_destroy                  (GtkObject          *object);
-static void        gantt_chart_style_set                (GtkWidget          *widget,
-							 GtkStyle           *prev_style);
+static void        gantt_chart_destroy                  (GtkWidget          *widget);
+static void        gantt_chart_style_updated            (GtkWidget          *widget);
 static void        gantt_chart_realize                  (GtkWidget          *widget);
 static void        gantt_chart_unrealize                (GtkWidget          *widget);
 static void        gantt_chart_map                      (GtkWidget          *widget);
 static void        gantt_chart_size_allocate            (GtkWidget          *widget,
 							 GtkAllocation      *allocation);
-static void        gantt_chart_set_adjustments          (PlannerGanttChart       *chart,
-							 GtkAdjustment      *hadj,
+static void        gantt_chart_set_hadjustment          (PlannerGanttChart  *chart,
+							 GtkAdjustment      *hadj);
+static void        gantt_chart_set_vadjustment          (PlannerGanttChart  *chart,
 							 GtkAdjustment      *vadj);
 static void        gantt_chart_row_changed              (GtkTreeModel       *model,
 							 GtkTreePath        *path,
@@ -216,8 +224,8 @@ static void        gantt_chart_tree_traverse            (TreeNode           *nod
 							 TreeFunc            func,
 							 gpointer            data);
 
-static guint         signals[LAST_SIGNAL];
-static GtkVBoxClass *parent_class = NULL;
+static guint        signals[LAST_SIGNAL];
+static GtkBoxClass *parent_class = NULL;
 
 
 GType
@@ -238,8 +246,16 @@ planner_gantt_chart_get_type (void)
 			(GInstanceInitFunc) gantt_chart_init
 		};
 
-		type = g_type_register_static (GTK_TYPE_VBOX, "PlannerGanttChart",
+		static const GInterfaceInfo scrollable_info = {
+			(GInterfaceInitFunc) NULL,
+			NULL,
+			NULL
+		};
+
+		type = g_type_register_static (GTK_TYPE_BOX, "PlannerGanttChart",
 					       &info, 0);
+
+		g_type_add_interface_static (type, GTK_TYPE_SCROLLABLE, &scrollable_info);
 	}
 
 	return type;
@@ -249,39 +265,24 @@ static void
 gantt_chart_class_init (PlannerGanttChartClass *class)
 {
 	GObjectClass      *o_class;
-	GtkObjectClass    *object_class;
 	GtkWidgetClass    *widget_class;
 
 	parent_class = g_type_class_peek_parent (class);
 
 	o_class         = (GObjectClass *) class;
-	object_class    = (GtkObjectClass *) class;
 	widget_class    = (GtkWidgetClass *) class;
 
 	o_class->set_property = gantt_chart_set_property;
 	o_class->get_property = gantt_chart_get_property;
 	o_class->finalize     = gantt_chart_finalize;
 
-	object_class->destroy = gantt_chart_destroy;
-
-	widget_class->style_set     = gantt_chart_style_set;
+	widget_class->destroy       = gantt_chart_destroy;
+	widget_class->style_updated = gantt_chart_style_updated;
 	widget_class->realize       = gantt_chart_realize;
 	widget_class->map           = gantt_chart_map;
 	widget_class->unrealize     = gantt_chart_unrealize;
 	widget_class->size_allocate = gantt_chart_size_allocate;
 
-	class->set_scroll_adjustments = gantt_chart_set_adjustments;
-
-	widget_class->set_scroll_adjustments_signal =
-		g_signal_new ("set_scroll_adjustments",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (PlannerGanttChartClass, set_scroll_adjustments),
-			      NULL, NULL,
-			      planner_marshal_VOID__OBJECT_OBJECT,
-			      G_TYPE_NONE, 2,
-			      GTK_TYPE_ADJUSTMENT, GTK_TYPE_ADJUSTMENT);
-
 	signals[STATUS_UPDATED] =
 		g_signal_new ("status-updated",
 			      G_TYPE_FROM_CLASS (class),
@@ -301,6 +302,12 @@ gantt_chart_class_init (PlannerGanttChartClass *class)
 			      G_TYPE_NONE, 1,
 			      MRP_TYPE_RESOURCE);
 
+	/* GtkScrollable interface properties */
+	g_object_class_override_property (o_class, PROP_HADJUSTMENT,    "hadjustment");
+	g_object_class_override_property (o_class, PROP_VADJUSTMENT,    "vadjustment");
+	g_object_class_override_property (o_class, PROP_HSCROLL_POLICY, "hscroll-policy");
+	g_object_class_override_property (o_class, PROP_VSCROLL_POLICY, "vscroll-policy");
+
 	/* Properties. */
 	g_object_class_install_property (o_class,
 					 PROP_MODEL,
@@ -364,8 +371,10 @@ gantt_chart_init (PlannerGanttChart *chart)
 			    0);		/* padding */
 
 	priv->canvas = GNOME_CANVAS (gnome_canvas_new ());
+	/* TODO: Consider porting these over to gtk3
 	priv->canvas->close_enough = 5;
 	gnome_canvas_set_center_scroll_region (priv->canvas, FALSE);
+	 */
 
 	/* Easiest way to get access to the chart from the canvas items. */
 	g_object_set_data (G_OBJECT (priv->canvas), "chart", chart);
@@ -390,15 +399,26 @@ gantt_chart_init (PlannerGanttChart *chart)
 	priv->relation_hash = g_hash_table_new (NULL, NULL);
 
 	priv->highlight_critical = planner_conf_get_bool (CRITICAL_PATH_KEY,
-							  NULL);
+							  "gantt");
 	priv->nonstandard_days   = planner_conf_get_bool (NOSTDDAYS_PATH_KEY,
-							  NULL);
-	priv->guidelines = planner_conf_get_bool (GUIDELINES_PATH_KEY, NULL);
+							  "gantt");
+	priv->guidelines = planner_conf_get_bool (GUIDELINES_PATH_KEY, "gantt");
 
 	g_object_set (G_OBJECT(chart->priv->background),
 			"show_guidelines",
 			priv->guidelines,
 			NULL);
+
+	/* TODO: Is this an OK way to share the adjustments? Probably could just set them in set_property instead for simplicity? */
+	g_object_bind_property (chart, "hadjustment",
+				priv->header, "hadjustment",
+				G_BINDING_DEFAULT);
+	g_object_bind_property (chart, "hadjustment",
+				priv->canvas, "hadjustment",
+				G_BINDING_DEFAULT);
+	g_object_bind_property (chart, "vadjustment",
+				priv->canvas, "vadjustment",
+				G_BINDING_DEFAULT);
 }
 
 static void
@@ -427,6 +447,21 @@ gantt_chart_set_property (GObject      *object,
 			      NULL);
 		gantt_chart_reflow (chart, TRUE);
 		break;
+	case PROP_HADJUSTMENT:
+		gantt_chart_set_hadjustment (chart, g_value_get_object (value));
+		break;
+	case PROP_VADJUSTMENT:
+		gantt_chart_set_vadjustment (chart, g_value_get_object (value));
+		break;
+	case PROP_HSCROLL_POLICY:
+		chart->priv->hscroll_policy = g_value_get_enum (value);
+		gtk_widget_queue_resize (GTK_WIDGET (chart));
+		break;
+	case PROP_VSCROLL_POLICY:
+		chart->priv->hscroll_policy = g_value_get_enum (value);
+		gtk_widget_queue_resize (GTK_WIDGET (chart));
+		break;
+
 	default:
 		break;
 	}
@@ -446,6 +481,18 @@ gantt_chart_get_property (GObject    *object,
 	case PROP_MODEL:
 		g_value_set_object (value, G_OBJECT (chart->priv->model));
 		break;
+	case PROP_HADJUSTMENT:
+		g_value_set_object (value, chart->priv->hadjustment);
+		break;
+	case PROP_VADJUSTMENT:
+		g_value_set_object (value, chart->priv->vadjustment);
+		break;
+	case PROP_HSCROLL_POLICY:
+		g_value_set_enum (value, chart->priv->hscroll_policy);
+		break;
+	case PROP_VSCROLL_POLICY:
+		g_value_set_enum (value, chart->priv->vscroll_policy);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -467,9 +514,9 @@ gantt_chart_finalize (GObject *object)
 }
 
 static void
-gantt_chart_destroy (GtkObject *object)
+gantt_chart_destroy (GtkWidget *widget)
 {
-	PlannerGanttChart *chart = PLANNER_GANTT_CHART (object);
+	PlannerGanttChart *chart = PLANNER_GANTT_CHART (widget);
 
 	planner_gantt_chart_set_model (chart, NULL);
 
@@ -484,42 +531,36 @@ gantt_chart_destroy (GtkObject *object)
 		chart->priv->model = NULL;
 	}
 
-	if (GTK_OBJECT_CLASS (parent_class)->destroy) {
-		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+	if (GTK_WIDGET_CLASS (parent_class)->destroy) {
+		(* GTK_WIDGET_CLASS (parent_class)->destroy) (widget);
 	}
 }
 
 static void
-gantt_chart_style_set (GtkWidget *widget,
-		       GtkStyle  *prev_style)
+gantt_chart_style_updated (GtkWidget *widget)
 {
 	PlannerGanttChart     *chart;
-	PlannerGanttChartPriv *priv;
 	PangoContext     *context;
 	PangoFontMetrics *metrics;
 
 	g_return_if_fail (PLANNER_IS_GANTT_CHART (widget));
 
-	if (GTK_WIDGET_CLASS (parent_class)->style_set) {
-		GTK_WIDGET_CLASS (parent_class)->style_set (widget,
-							    prev_style);
+	if (GTK_WIDGET_CLASS (parent_class)->style_updated) {
+		GTK_WIDGET_CLASS (parent_class)->style_updated (widget);
 	}
 
 	chart = PLANNER_GANTT_CHART (widget);
-	priv = chart->priv;
 
-	context = gtk_widget_get_pango_context (widget);
+	context = gtk_widget_get_pango_context (GTK_WIDGET (chart->priv->canvas));
 
-	metrics = pango_context_get_metrics (context,
-					     widget->style->font_desc,
-					     NULL);
+	metrics = pango_context_get_metrics (context, NULL, NULL);
 
-	f = 0.2 * pango_font_metrics_get_approximate_char_width (metrics) / PANGO_SCALE;
+	font_width_factor = 0.2 * pango_font_metrics_get_approximate_char_width (metrics) / PANGO_SCALE;
 
 	pango_font_metrics_unref(metrics);
 
 	/* Re-layout with the new factor. */
-	gantt_chart_set_zoom (PLANNER_GANTT_CHART (widget), priv->zoom);
+	gantt_chart_set_zoom (PLANNER_GANTT_CHART (widget), chart->priv->zoom);
 }
 
 static void
@@ -527,9 +568,10 @@ gantt_chart_realize (GtkWidget *widget)
 {
 	PlannerGanttChart     *chart;
 	PlannerGanttChartPriv *priv;
-	GdkColormap           *colormap;
-	GtkStyle              *style;
+	GtkCssProvider        *css_provider;
+	GtkStyleContext       *style_context;
 	GtkWidget             *canvas;
+	GError                *error = NULL;
 
 	chart = PLANNER_GANTT_CHART (widget);
 	priv = chart->priv;
@@ -541,11 +583,20 @@ gantt_chart_realize (GtkWidget *widget)
 	}
 
 	/* Set the background to white. */
-	style = gtk_style_copy (canvas->style);
-	colormap = gtk_widget_get_colormap (canvas);
-	gdk_color_white (colormap, &style->bg[GTK_STATE_NORMAL]);
-	gtk_widget_set_style (canvas, style);
-	gtk_style_unref (style);
+	css_provider = gtk_css_provider_new ();
+	gtk_css_provider_load_from_data (css_provider,
+					 "@define-color theme_bg_color white;",
+					 -1, &error);
+	style_context = gtk_widget_get_style_context (canvas);
+	if (error == NULL) {
+		gtk_style_context_add_provider (style_context,
+						GTK_STYLE_PROVIDER (css_provider),
+						GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	} else {
+		g_warning ("%s: %s", G_STRFUNC, error->message);
+		g_clear_error (&error);
+	}
+	g_object_unref (css_provider);
 
 	gantt_chart_set_zoom (chart, priv->zoom);
 }
@@ -589,64 +640,65 @@ gantt_chart_size_allocate (GtkWidget     *widget,
 	/* Force reflow (if we are mapped), since it looks smoother with less
 	 * jumping around.
 	 */
-	if (GTK_WIDGET_MAPPED (chart)) {
+	if (gtk_widget_get_mapped (GTK_WIDGET (chart))) {
 		planner_gantt_chart_reflow_now (chart);
 	}
 }
 
 static void
-gantt_chart_set_adjustments (PlannerGanttChart *chart,
-			     GtkAdjustment     *hadj,
-			     GtkAdjustment     *vadj)
+gantt_chart_set_hadjustment (PlannerGanttChart *chart,
+                             GtkAdjustment     *hadj)
 {
-	PlannerGanttChartPriv *priv;
-	gboolean               need_adjust = FALSE;
+	if (hadj && chart->priv->hadjustment == hadj)
+		return;
 
-	g_return_if_fail (hadj == NULL || GTK_IS_ADJUSTMENT (hadj));
-	g_return_if_fail (vadj == NULL || GTK_IS_ADJUSTMENT (vadj));
-
-	priv = chart->priv;
-
-	if (hadj == NULL) {
+	if (hadj)
+		g_return_if_fail (GTK_IS_ADJUSTMENT (hadj));
+	else
 		hadj = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 0.0, 0.0, 0.0, 0.0));
+
+	if (chart->priv->hadjustment != NULL) {
+		g_signal_handlers_disconnect_matched (chart->priv->hadjustment,
+						      G_SIGNAL_MATCH_DATA,
+						      0, 0, NULL, NULL,
+						      chart);
+		g_object_unref (chart->priv->hadjustment);
 	}
-	if (vadj == NULL) {
+
+	/* TODO: value-changed handler? If not adding, disconnecting above is probably unnecessary too */
+	chart->priv->hadjustment = g_object_ref_sink (hadj);
+	/* TODO: Do we need to set the initial hadj values? */
+	/* TODO: Share the hadjustment with header and canvas? */
+
+	g_object_notify (G_OBJECT (chart), "hadjustment");
+}
+
+static void
+gantt_chart_set_vadjustment (PlannerGanttChart *chart,
+                             GtkAdjustment     *vadj)
+{
+	if (vadj && chart->priv->vadjustment == vadj)
+		return;
+
+	if (vadj)
+		g_return_if_fail (GTK_IS_ADJUSTMENT (vadj));
+	else
 		vadj = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 0.0, 0.0, 0.0, 0.0));
+
+	if (chart->priv->vadjustment != NULL) {
+		g_signal_handlers_disconnect_matched (chart->priv->vadjustment,
+						      G_SIGNAL_MATCH_DATA,
+						      0, 0, NULL, NULL,
+						      chart);
+		g_object_unref (chart->priv->vadjustment);
 	}
 
-	if (priv->hadjustment && (priv->hadjustment != hadj)) {
-		g_object_unref (priv->hadjustment);
-	}
+	/* TODO: value-changed handler? If not adding, disconnecting above is probably unnecessary too */
+	chart->priv->vadjustment = g_object_ref_sink (vadj);
+	/* TODO: Do we need to set the initial vadj values? */
+	/* TODO: Share the vadjustment with canvas? */
 
-	if (priv->vadjustment && (priv->vadjustment != vadj)) {
-		g_object_unref (priv->vadjustment);
-	}
-
-	if (priv->hadjustment != hadj) {
-		priv->hadjustment = hadj;
-		g_object_ref (priv->hadjustment);
-		gtk_object_sink (GTK_OBJECT (priv->hadjustment));
-
-		gtk_widget_set_scroll_adjustments (priv->header,
-						   hadj,
-						   NULL);
-
-		need_adjust = TRUE;
-	}
-
-	if (priv->vadjustment != vadj) {
-		priv->vadjustment = vadj;
-		g_object_ref (priv->vadjustment);
-		gtk_object_sink (GTK_OBJECT (priv->vadjustment));
-
-		need_adjust = TRUE;
-	}
-
-	if (need_adjust) {
-		gtk_widget_set_scroll_adjustments (GTK_WIDGET (priv->canvas),
-						   hadj,
-						   vadj);
-	}
+	g_object_notify (G_OBJECT (chart), "vadjustment");
 }
 
 static void
@@ -747,7 +799,7 @@ gantt_chart_remove_children (PlannerGanttChart *chart,
 	}
 
 	if (node->item) {
-		gtk_object_destroy (GTK_OBJECT (node->item));
+		g_object_run_dispose (G_OBJECT (node->item));
 		node->item = NULL;
 	}
 	node->task = NULL;
@@ -880,7 +932,7 @@ gantt_chart_build_tree (PlannerGanttChart *chart)
 	GtkTreePath *path;
 	GHashTable  *hash;
 
-	path = gtk_tree_path_new_root ();
+	path = gtk_tree_path_new_first ();
 	if (!gtk_tree_model_get_iter (chart->priv->model, &iter, path)) {
 		gtk_tree_path_free (path);
 		return;
@@ -973,7 +1025,7 @@ gantt_chart_reflow_idle (PlannerGanttChart *chart)
 		height = priv->height;
 	}
 
-	allocation = GTK_WIDGET (priv->canvas)->allocation;
+	gtk_widget_get_allocation (GTK_WIDGET (priv->canvas), &allocation);
 
 	t1 = priv->project_start;
 	t2 = priv->last_time;
@@ -1025,7 +1077,7 @@ gantt_chart_reflow_idle (PlannerGanttChart *chart)
 void
 planner_gantt_chart_reflow_now (PlannerGanttChart *chart)
 {
-	if (!GTK_WIDGET_MAPPED (chart)) {
+	if (! gtk_widget_get_mapped (GTK_WIDGET (chart))) {
 		return;
 	}
 
@@ -1035,7 +1087,7 @@ planner_gantt_chart_reflow_now (PlannerGanttChart *chart)
 static void
 gantt_chart_reflow (PlannerGanttChart *chart, gboolean height_changed)
 {
-	if (!GTK_WIDGET_MAPPED (chart)) {
+	if (! gtk_widget_get_mapped (GTK_WIDGET (chart))) {
 		return;
 	}
 
@@ -1065,7 +1117,6 @@ gantt_chart_insert_task (PlannerGanttChart *chart,
 				      "scale", SCALE (priv->zoom),
 				      "zoom", priv->zoom,
 				      NULL);
-	planner_gantt_row_init_menu (PLANNER_GANTT_ROW (item));
 
 	tree_node = gantt_chart_tree_node_new ();
 	tree_node->item = item;
@@ -1140,7 +1191,9 @@ planner_gantt_chart_new_with_model (GtkTreeModel *model)
 {
 	PlannerGanttChart *chart;
 
-	chart = PLANNER_GANTT_CHART (gtk_type_new (planner_gantt_chart_get_type ()));
+	chart = PLANNER_GANTT_CHART (g_object_new (PLANNER_TYPE_GANTT_CHART,
+						   "orientation", GTK_ORIENTATION_VERTICAL,
+						   NULL));
 
 	if (model) {
 		planner_gantt_chart_set_model (chart, model);
@@ -1275,7 +1328,7 @@ gantt_chart_relation_removed (MrpTask           *task,
 	if (arrow != NULL) {
 		g_hash_table_remove (chart->priv->relation_hash, relation);
 
-		gtk_object_destroy (GTK_OBJECT (arrow));
+		g_object_run_dispose (G_OBJECT (arrow));
 		gantt_chart_reflow (chart, FALSE);
 	}
 }
@@ -1750,12 +1803,14 @@ static mrptime
 gantt_chart_get_center (PlannerGanttChart *chart)
 {
 	PlannerGanttChartPriv *priv;
+	GtkAllocation          allocation;
 	gint                   x1, width, x;
 
 	priv = chart->priv;
 
 	gnome_canvas_get_scroll_offsets (priv->canvas, &x1, NULL);
-	width = GTK_WIDGET (priv->canvas)->allocation.width;
+	gtk_widget_get_allocation (GTK_WIDGET (priv->canvas), &allocation);
+	width = allocation.width;
 
 	x = x1 + width / 2 - PADDING;
 
@@ -1769,12 +1824,14 @@ gantt_chart_set_center (PlannerGanttChart *chart, mrptime t)
 {
 	PlannerGanttChartPriv *priv;
 	gint                   x, x1, width;
+	GtkAllocation          allocation;
 
 	priv = chart->priv;
 
 	x = floor (t * SCALE (priv->zoom) + 0.5);
 
-	width = GTK_WIDGET (priv->canvas)->allocation.width;
+	gtk_widget_get_allocation (GTK_WIDGET (priv->canvas), &allocation);
+	width = allocation.width;
 
 	x1 = x - width / 2 + PADDING;
 
@@ -1839,6 +1896,7 @@ planner_gantt_chart_zoom_to_fit (PlannerGanttChart *chart)
 	gdouble                t;
 	gdouble                zoom;
 	gdouble                alloc;
+	GtkAllocation          allocation;
 
 	g_return_if_fail (PLANNER_IS_GANTT_CHART (chart));
 
@@ -1847,7 +1905,8 @@ planner_gantt_chart_zoom_to_fit (PlannerGanttChart *chart)
 		return;
 	}
 
-	alloc = GTK_WIDGET (chart)->allocation.width - PADDING * 2;
+	gtk_widget_get_allocation (GTK_WIDGET (chart), &allocation);
+	alloc = allocation.width - PADDING * 2;
 
 	zoom = planner_scale_clamp_zoom (ZOOM (alloc / t));
 	gantt_chart_set_zoom (chart, zoom);
@@ -1916,7 +1975,7 @@ planner_gantt_chart_set_highlight_critical_tasks (PlannerGanttChart *chart,
 
 	gtk_widget_queue_draw (GTK_WIDGET (priv->canvas));
 
-	planner_conf_set_bool (CRITICAL_PATH_KEY, state, NULL);
+	planner_conf_set_bool (CRITICAL_PATH_KEY, state, "gantt");
 }
 
 void
@@ -1942,7 +2001,7 @@ planner_gantt_chart_set_show_guidelines (PlannerGanttChart *chart,
 
 	gtk_widget_queue_draw (GTK_WIDGET (priv->canvas));
 
-	planner_conf_set_bool (GUIDELINES_PATH_KEY, state, NULL);
+	planner_conf_set_bool (GUIDELINES_PATH_KEY, state, "gantt");
 }
 
 gboolean
@@ -1979,7 +2038,7 @@ planner_gantt_chart_set_nonstandard_days (PlannerGanttChart *chart,
 
 	gtk_widget_queue_draw (GTK_WIDGET (priv->canvas));
 
-	planner_conf_set_bool (NOSTDDAYS_PATH_KEY, state, NULL);
+	planner_conf_set_bool (NOSTDDAYS_PATH_KEY, state, "gantt");
 }
 
 gboolean
