@@ -635,9 +635,9 @@ gantt_model_get_column_type (GtkTreeModel *tree_model,
 	case COL_NAME:
 		return G_TYPE_STRING;
 	case COL_START:
-		return G_TYPE_LONG;
+		return G_TYPE_INT64;
 	case COL_FINISH:
-		return G_TYPE_LONG;
+		return G_TYPE_INT64;
 	case COL_DURATION:
 		return G_TYPE_INT;
 	case COL_WORK:
@@ -821,13 +821,13 @@ gantt_model_get_value (GtkTreeModel *tree_model,
 		break;
 
 	case COL_START:
-		g_value_init (value, G_TYPE_LONG);
-		g_value_set_long (value, mrp_task_get_work_start (task));
+		g_value_init (value, G_TYPE_INT64);
+		g_value_set_int64 (value, mrp_task_get_work_start (task));
 		break;
 
 	case COL_FINISH:
-		g_value_init (value, G_TYPE_LONG);
-		g_value_set_long (value, mrp_task_get_finish (task));
+		g_value_init (value, G_TYPE_INT64);
+		g_value_set_int64 (value, mrp_task_get_finish (task));
 		break;
 
 	case COL_DURATION:
