@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -30,7 +30,6 @@
 #include <libplanner/mrp-task.h>
 #include "libplanner/mrp-paths.h"
 #include "planner-gantt-view.h"
-#include "planner-cell-renderer-date.h"
 #include "planner-task-dialog.h"
 #include "planner-resource-dialog.h"
 #include "planner-gantt-model.h"
@@ -49,7 +48,7 @@ struct _PlannerGanttViewPriv {
 	GtkUIManager          *ui_manager;
 	GtkActionGroup        *actions;
 	guint                  merged_id;
-	gulong                 expose_id;
+	gulong                 draw_signal_id;
 };
 
 static void          gantt_view_finalize                  (GObject           *object);
@@ -92,8 +91,8 @@ static void          gantt_view_nonstandard_days_cb       (GtkAction         *ac
 							   gpointer           data);
 static void          gantt_view_edit_columns_cb           (GtkAction         *action,
 							   gpointer           data);
-static gboolean      gantt_view_expose_cb                 (GtkWidget         *widget,
-							   GdkEventExpose    *event,
+static gboolean      gantt_view_draw_cb                   (GtkWidget         *widget,
+							   cairo_t           *cr,
 							   gpointer           user_data);
 static void          gantt_view_update_row_height         (PlannerGanttView  *view);
 static void          gantt_view_tree_style_set_cb         (GtkWidget         *tree,
@@ -208,10 +207,12 @@ gantt_view_chart_scroll_event (GtkWidget * gki, GdkEventScroll * event, PlannerG
 	gboolean dontpropagate = FALSE;
 	gboolean can_in, can_out;
 	PlannerGanttViewPriv *priv;
+	gdouble delta_y;
 
 	if (event->state & GDK_CONTROL_MASK) {
 		priv = view->priv;
 		planner_gantt_chart_can_zoom (PLANNER_GANTT_CHART (priv->gantt), &can_in, &can_out);
+		/* TODO: Why is the canvas area getting GDK_SCROLL_SMOOTH but header not? */
 		switch (event->direction) {
 			case GDK_SCROLL_UP: {
 				dontpropagate = TRUE;
@@ -223,7 +224,17 @@ gantt_view_chart_scroll_event (GtkWidget * gki, GdkEventScroll * event, PlannerG
 				dontpropagate = TRUE;
 				if (can_out)
 					gantt_view_zoom_out_cb  (NULL, view);
-			        break;
+				break;
+			case GDK_SCROLL_SMOOTH:
+				/* TODO: Test over with different input methods (that give values other than 1 or -1),
+				 * possibly gather deltas together to handle the smoothness */
+				/* TODO: First wheel event seems to carry a delta of zero and thus do nothing */
+				gdk_event_get_scroll_deltas ((GdkEvent *)event, NULL, &delta_y);
+				if (can_in && delta_y < 0)
+					gantt_view_zoom_in_cb (NULL, view);
+				else if (can_out && delta_y > 0)
+					gantt_view_zoom_out_cb (NULL, view);
+				break;
 			default:
 				break;
 		}
@@ -498,11 +509,11 @@ gantt_view_task_inserted_cb (MrpProject   *project,
 			     MrpTask      *task,
 			     PlannerGanttView *view)
 {
-	if(view->priv->expose_id == 0) {
-		view->priv->expose_id = g_signal_connect_after (view->priv->tree,
-								"expose_event",
-								G_CALLBACK (gantt_view_expose_cb),
-								view);
+	if(view->priv->draw_signal_id == 0) {
+		view->priv->draw_signal_id = g_signal_connect_after (view->priv->tree,
+								     "draw",
+								     G_CALLBACK (gantt_view_draw_cb),
+								     view);
 	}
 }
 
@@ -520,50 +531,14 @@ gantt_view_project_loaded_cb (MrpProject  *project,
 	planner_gantt_chart_set_model (PLANNER_GANTT_CHART (view->priv->gantt),
 				       model);
 
-	view->priv->expose_id = g_signal_connect_after (view->priv->tree,
-							"expose_event",
-							G_CALLBACK (gantt_view_expose_cb),
-							view);
+	view->priv->draw_signal_id = g_signal_connect_after (view->priv->tree,
+							     "draw",
+							     G_CALLBACK (gantt_view_draw_cb),
+							     view);
 
 	g_object_unref (model);
 }
 
-static void
-gantt_view_tree_view_size_request_cb (GtkWidget      *widget,
-				      GtkRequisition *req,
-				      gpointer        data)
-{
-	req->height = -1;
-}
-
-static gboolean
-gantt_view_tree_view_scroll_event_cb (GtkWidget      *widget,
-				      GdkEventScroll *event,
-				      gpointer        data)
-{
-	GtkAdjustment *adj;
-	GtkTreeView   *tv = GTK_TREE_VIEW (widget);
-	gdouble        new_value;
-
-	if (event->direction != GDK_SCROLL_UP &&
-	    event->direction != GDK_SCROLL_DOWN) {
-		return FALSE;
-	}
-
-	adj = gtk_tree_view_get_vadjustment (tv);
-
-	if (event->direction == GDK_SCROLL_UP) {
-		new_value = adj->value - adj->page_increment / 2;
-	} else {
-		new_value = adj->value + adj->page_increment / 2;
-	}
-
-	new_value = CLAMP (new_value, adj->lower, adj->upper - adj->page_size);
-	gtk_adjustment_set_value (adj, new_value);
-
-	return TRUE;
-}
-
 static void
 gantt_view_tree_view_columns_changed_cb (GtkTreeView *tree_view,
 					 PlannerGanttView *view)
@@ -589,10 +564,8 @@ gantt_view_create_widget (PlannerGanttView *view)
 	PlannerGanttViewPriv  *priv;
 	GtkWidget        *tree;
 	GtkWidget        *sw;
-	GtkWidget        *frame;
-	GtkWidget        *vbox;
 	GtkWidget        *hpaned;
-	GtkAdjustment    *hadj, *vadj;
+	GtkAdjustment    *vadj;
 	GtkTreeModel     *model;
 	MrpProject       *project;
 	GtkTreeSelection *selection;
@@ -695,46 +668,29 @@ gantt_view_create_widget (PlannerGanttView *view)
 			  G_CALLBACK (gantt_view_relations_changed_cb),
 			  view);
 
-	vbox = gtk_vbox_new (FALSE, 3);
-
-	gtk_box_pack_start (GTK_BOX (vbox), tree, TRUE, TRUE, 0);
-
-	hadj = gtk_tree_view_get_hadjustment (GTK_TREE_VIEW (tree));
-	gtk_box_pack_start (GTK_BOX (vbox), gtk_hscrollbar_new (hadj), FALSE, TRUE, 0);
-
-	frame = gtk_frame_new (NULL);
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
-	gtk_container_add (GTK_CONTAINER (frame), vbox);
-
-	hpaned = gtk_hpaned_new ();
-	gtk_paned_add1 (GTK_PANED (hpaned), frame);
-
-	g_signal_connect_after (tree,
-				"size_request",
-				G_CALLBACK (gantt_view_tree_view_size_request_cb),
-				NULL);
-
-	g_signal_connect_after (tree,
-				"scroll_event",
-				G_CALLBACK (gantt_view_tree_view_scroll_event_cb),
-				view);
-
-	hadj = GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 0, 90, 250, 2000));
-	vadj = gtk_tree_view_get_vadjustment (GTK_TREE_VIEW (tree));
-
-	sw = gtk_scrolled_window_new (hadj, vadj);
+	sw = gtk_scrolled_window_new (NULL, NULL);
+	/* TODO: Consider changing vertical policy to GTK_POLICY_EXTERNAL once we depend on gtk 3.16 */
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
-					GTK_POLICY_ALWAYS,
+					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
+	gtk_container_add (GTK_CONTAINER (sw), tree);
 
-	frame = gtk_frame_new (NULL);
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
-	gtk_container_add (GTK_CONTAINER (frame), sw);
+	hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
+	gtk_paned_add1 (GTK_PANED (hpaned), sw);
+
+	/* TODO: Exclude the scrollbar from the gantt header, like the GtkTreeView does */
+	vadj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (sw));
+	sw = gtk_scrolled_window_new (NULL, vadj);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+					GTK_POLICY_AUTOMATIC,
+					GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
 
 	gtk_container_add (GTK_CONTAINER (sw),
 			   GTK_WIDGET (priv->gantt));
 
-	gtk_paned_add2 (GTK_PANED (hpaned), frame);
+	gtk_paned_add2 (GTK_PANED (hpaned), sw);
 
 	gtk_paned_set_position (GTK_PANED (hpaned), 250);
 
@@ -1016,7 +972,7 @@ gantt_view_update_row_height (PlannerGanttView *view)
 	for (l = cols; l; l = l->next) {
 		col = l->data;
 
-		gtk_widget_size_request (col->button, &req);
+		gtk_widget_get_preferred_size (gtk_tree_view_column_get_button (col), &req, NULL);
 		header_height = MAX (header_height, req.height);
 
 		gtk_tree_view_column_cell_get_size (col,
@@ -1047,16 +1003,16 @@ gantt_view_update_row_height (PlannerGanttView *view)
 }
 
 static gboolean
-gantt_view_expose_cb (GtkWidget      *widget,
-		      GdkEventExpose *event,
-		      gpointer        data)
+gantt_view_draw_cb (GtkWidget *widget,
+                    cairo_t   *cr,
+                    gpointer   data)
 {
 	PlannerGanttView     *view = PLANNER_GANTT_VIEW (data);
 
 	gantt_view_update_row_height (view);
 
 	g_signal_handler_disconnect (view->priv->tree,
-				     view->priv->expose_id);
+				     view->priv->draw_signal_id);
 
 	return FALSE;
 }
@@ -1232,60 +1188,20 @@ gantt_view_save_columns (PlannerGanttView *view)
 
 	priv = view->priv;
 
-	planner_view_column_save_helper (PLANNER_VIEW (view), GTK_TREE_VIEW (priv->tree));
+	planner_view_column_save_helper (PLANNER_VIEW (view),
+					 GTK_TREE_VIEW (priv->tree), "gantt");
 }
 
 static void
 gantt_view_load_columns (PlannerGanttView *view)
 {
 	PlannerGanttViewPriv *priv;
-	GList                *columns, *l;
-	GtkTreeViewColumn    *column;
-	const gchar          *id;
-	gint                  i;
 
 	priv = view->priv;
 
 	/* Load the columns. */
-	planner_view_column_load_helper (PLANNER_VIEW (view), GTK_TREE_VIEW (priv->tree));
-
-	/* Make things a bit more robust by setting defaults if we don't get any
-	 * visible columns. Should be done through a schema instead (but we'll
-	 * keep this since a lot of people get bad installations when installing
-	 * themselves).
-	 */
-	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (priv->tree));
-	i = 0;
-	for (l = columns; l; l = l->next) {
-		if (gtk_tree_view_column_get_visible (l->data)) {
-			i++;
-		}
-	}
-
-	if (i == 0) {
-		for (l = columns; l; l = l->next) {
-			column = l->data;
-
-			if (g_object_get_data (G_OBJECT (column), "custom")) {
-				continue;
-			}
-
-			id = g_object_get_data (G_OBJECT (column), "id");
-			if (!id) {
-				continue;
-			}
-
-			if (strcmp (id, "wbs") == 0 ||
-			    strcmp (id, "name") == 0 ||
-			    strcmp (id, "work") == 0) {
-				gtk_tree_view_column_set_visible (column, TRUE);
-			} else {
-				gtk_tree_view_column_set_visible (column, FALSE);
-			}
-		}
-	}
-
-	g_list_free (columns);
+	planner_view_column_load_helper (PLANNER_VIEW (view),
+					 GTK_TREE_VIEW (priv->tree), "gantt");
 }
 
 PlannerView *
