@@ -25,7 +25,6 @@
 #include <config.h>
 #include <time.h>
 #include <string.h>
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libplanner/mrp-resource.h>
@@ -35,6 +34,7 @@
 
 #include "planner-format.h"
 #include "planner-resource-dialog.h"
+#include "planner-util.h"
 
 typedef struct {
 	PlannerWindow *main_window;
@@ -248,123 +248,100 @@ resource_dialog_find_calendar (DialogData  *data,
 }
 
 static void
-resource_dialog_setup_option_menu (GtkWidget     *option_menu,
-				   GCallback      func,
-				   gpointer       user_data,
-				   gconstpointer  str1, ...)
+resource_dialog_setup_combobox (GtkWidget *combo)
 {
-	GtkWidget    *menu;
-	GtkWidget    *menu_item;
-	gint          i;
-	va_list       args;
-	gconstpointer str;
-	gint          type;
+	GtkComboBoxText *combo_text = GTK_COMBO_BOX_TEXT (combo);
 
-       	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-	if (menu) {
-		gtk_widget_destroy (menu);
-	}
+	gtk_combo_box_text_append_text (combo_text, _("Work"));
+	gtk_combo_box_text_append_text (combo_text, _("Material"));
+}
 
-	menu = gtk_menu_new ();
+static void
+menu_groups_name (GtkCellLayout   *layout,
+                  GtkCellRenderer *cell,
+                  GtkTreeModel    *model,
+                  GtkTreeIter     *iter,
+                  gpointer         user_data)
+{
+	MrpGroup *group;
+	const gchar *name;
 
-	va_start (args, str1);
-	for (str = str1, i = 0; str != NULL; str = va_arg (args, gpointer), i++) {
-		menu_item = gtk_menu_item_new_with_label (str);
-		gtk_widget_show (menu_item);
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
-
-		type = va_arg (args, gint);
-
-		g_object_set_data (G_OBJECT (menu_item),
-				   "data",
-				   GINT_TO_POINTER (type));
-		if (func) {
-			g_signal_connect (menu_item,
-					  "activate",
-					  func,
-					  user_data);
+	gtk_tree_model_get (model, iter, 0, &group, -1);
+	if (!group) {
+		name = _("(None)");
+	} else {
+		name = mrp_group_get_name (group);
+		if (!name) {
+			name = _("(No name)");
 		}
 	}
-	va_end (args);
-
-	gtk_widget_show (menu);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
+	g_object_set (cell,
+		      "text", name,
+		      NULL);
 }
 
 static void
 resource_dialog_setup_option_groups (GtkWidget *menu_groups,
 				     GList     *groups)
 {
-	GtkWidget *menu;
-	GtkWidget *menu_item;
-	gchar     *name;
-	GList     *l;
+	GtkListStore    *store;
+	GtkTreeIter      iter;
+	GList           *l;
+	GtkCellRenderer *renderer;
 
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (menu_groups));
-
-	if (menu) {
-		gtk_widget_destroy (menu);
-	}
-
-	menu = gtk_menu_new ();
+	store = gtk_list_store_new (1, MRP_TYPE_GROUP);
+	gtk_combo_box_set_model (GTK_COMBO_BOX (menu_groups), GTK_TREE_MODEL (store));
+	g_object_unref (store);
 
 	/* Put "no group" at the top. */
-	menu_item = gtk_menu_item_new_with_label (_("(None)"));
-	gtk_widget_show (menu_item);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter,
+			    0, NULL,
+			    -1);
 
 	for (l = groups; l; l = l->next) {
-		g_object_get (G_OBJECT (l->data),
-			      "name", &name,
-			      NULL);
+		MrpGroup *group = l->data;
 
-		if (name == NULL) {
-			name = g_strdup (_("(No name)"));
-		}
-
-		menu_item = gtk_menu_item_new_with_label (name);
-		gtk_widget_show (menu_item);
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
-
-		g_object_set_data (G_OBJECT (menu_item),
-				   "data",
-				   l->data);
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+				    0, group,
+				    -1);
 	}
 
-	gtk_widget_show (menu);
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (menu_groups), menu);
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (menu_groups),
+				    renderer, TRUE);
+	gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (menu_groups),
+					    renderer,
+					    menu_groups_name,
+					    NULL, NULL);
 }
 
 static gint
-resource_dialog_option_menu_get_type_selected (GtkWidget *option_menu)
+resource_dialog_get_type_selected (GtkWidget *combo)
 {
-	GtkWidget *menu;
-	GtkWidget *item;
-	gint       ret;
-
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-
-	item = gtk_menu_get_active (GTK_MENU (menu));
-
-	ret = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "data"));
-
-	return ret;
+	switch (gtk_combo_box_get_active (GTK_COMBO_BOX (combo))) {
+	case 0:
+		return MRP_RESOURCE_TYPE_WORK;
+	case 1:
+		return MRP_RESOURCE_TYPE_MATERIAL;
+	default:
+		return MRP_RESOURCE_TYPE_NONE;
+	}
 }
 
 static MrpGroup *
-resource_dialog_option_menu_get_group_selected (GtkWidget *option_menu)
+resource_dialog_get_group_selected (GtkWidget *combo)
 {
-	GtkWidget *menu;
-	GtkWidget *item;
-	MrpGroup  *ret;
+	GtkTreeIter  iter;
+	MrpGroup    *group;
 
-	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
-
-	item = gtk_menu_get_active (GTK_MENU (menu));
-
-	ret = g_object_get_data (G_OBJECT (item), "data");
-
-	return ret;
+	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter);
+	gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (combo)),
+			    &iter,
+			    0, &group,
+			    -1);
+	return group;
 }
 
 static void
@@ -977,7 +954,7 @@ resource_dialog_notify_type_cb (MrpResource *resource,
 		break;
 	}
 
-	gtk_option_menu_set_history (GTK_OPTION_MENU (data->type_menu), index);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (data->type_menu), index);
 
 	g_signal_handlers_unblock_by_func (data->type_menu,
 					   resource_dialog_type_changed_cb,
@@ -991,7 +968,7 @@ resource_dialog_type_changed_cb (GtkWidget  *w,
 	MrpResourceType  type;
 	GValue           value = { 0 };
 
-	type = resource_dialog_option_menu_get_type_selected (data->type_menu);
+	type = resource_dialog_get_type_selected (data->type_menu);
 
 	g_value_init (&value, G_TYPE_INT);
 	g_value_set_int (&value, type);
@@ -1039,7 +1016,7 @@ resource_dialog_notify_group_cb (MrpResource *resource,
 		index = g_list_index (groups, group) + 1;
 	}
 
-	gtk_option_menu_set_history (GTK_OPTION_MENU (data->group_menu), index);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (data->group_menu), index);
 
 	g_signal_handlers_unblock_by_func (data->group_menu,
 					   resource_dialog_group_changed_cb,
@@ -1053,7 +1030,7 @@ resource_dialog_group_changed_cb (GtkWidget  *w,
 	MrpGroup    *group;
 	GValue       value = { 0 };
 
-	group = resource_dialog_option_menu_get_group_selected (data->group_menu);
+	group = resource_dialog_get_group_selected (data->group_menu);
 
 	g_value_init (&value, MRP_TYPE_GROUP);
 	g_value_set_object (&value, group);
@@ -1586,8 +1563,8 @@ resource_dialog_setup_calendar_tree_view (DialogData *data)
 	tree_view = GTK_TREE_VIEW (data->calendar_tree_view);
 
 	model = resource_dialog_create_calendar_model (data);
-
 	gtk_tree_view_set_model (tree_view, model);
+	g_object_unref (model);
 
 	col = gtk_tree_view_column_new ();
 
@@ -1664,7 +1641,7 @@ GtkWidget *
 planner_resource_dialog_new (PlannerWindow *window,
 			     MrpResource  *resource)
 {
-	GladeXML        *glade;
+	GtkBuilder      *builder;
 	GtkWidget       *dialog;
 	GtkWidget       *w;
 	DialogData      *data;
@@ -1676,7 +1653,6 @@ planner_resource_dialog_new (PlannerWindow *window,
 	GList           *groups;
 	gint             index = 0;
 	gchar           *note;
-	gchar           *filename;
 
 	g_return_val_if_fail (PLANNER_IS_WINDOW (window), NULL);
 	g_return_val_if_fail (MRP_IS_RESOURCE (resource), NULL);
@@ -1693,18 +1669,9 @@ planner_resource_dialog_new (PlannerWindow *window,
 
 	g_object_get (resource, "project", &project, NULL);
 
-	filename = mrp_paths_get_glade_dir ("resource-dialog.glade");
-	glade = glade_xml_new (filename,
-			       NULL,
-			       GETTEXT_PACKAGE);
-	g_free (filename);
+	builder = gtk_builder_new_from_resource ("/app/drey/Planner/ui/resource-dialog.ui");
 
-	if (!glade) {
-		g_warning ("Could not create resource dialog.");
-		return NULL;
-	}
-
-	dialog = glade_xml_get_widget (glade, "resource_dialog");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "resource_dialog"));
 
 	data = g_new0 (DialogData, 1);
 
@@ -1731,14 +1698,14 @@ planner_resource_dialog_new (PlannerWindow *window,
 			  data);
 
 
-	data->name_entry = glade_xml_get_widget (glade, "entry_name");
-	data->short_name_entry = glade_xml_get_widget (glade, "entry_short_name");
-	data->type_menu = glade_xml_get_widget (glade, "menu_type");
-	data->group_menu = glade_xml_get_widget (glade, "menu_group");
-	data->email_entry = glade_xml_get_widget (glade, "entry_email");
-	data->cost_entry = glade_xml_get_widget (glade, "entry_cost");
-	data->calendar_tree_view = glade_xml_get_widget (glade, "calendar_treeview");
-	data->note_textview = glade_xml_get_widget (glade, "note_textview");
+	data->name_entry = GTK_WIDGET (gtk_builder_get_object (builder, "entry_name"));
+	data->short_name_entry = GTK_WIDGET (gtk_builder_get_object (builder, "entry_short_name"));
+	data->type_menu = GTK_WIDGET (gtk_builder_get_object (builder, "menu_type"));
+	data->group_menu = GTK_WIDGET (gtk_builder_get_object (builder, "menu_group"));
+	data->email_entry = GTK_WIDGET (gtk_builder_get_object (builder, "entry_email"));
+	data->cost_entry = GTK_WIDGET (gtk_builder_get_object (builder, "entry_cost"));
+	data->calendar_tree_view = GTK_WIDGET (gtk_builder_get_object (builder, "calendar_treeview"));
+	data->note_textview = GTK_WIDGET (gtk_builder_get_object (builder, "note_textview"));
 
 	data->note_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (data->note_textview));
 
@@ -1766,19 +1733,19 @@ planner_resource_dialog_new (PlannerWindow *window,
 			  data);
 
 
-	w = glade_xml_get_widget (glade, "calendar_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "calendar_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (resource_dialog_edit_calendar_clicked_cb),
 			  data);
 
-	w = glade_xml_get_widget (glade, "stamp_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "stamp_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (resource_dialog_note_stamp_clicked_cb),
 			  data);
 
-	w = glade_xml_get_widget (glade, "close_button");
+	w = GTK_WIDGET (gtk_builder_get_object (builder, "close_button"));
 	g_signal_connect (w,
 			  "clicked",
 			  G_CALLBACK (resource_dialog_close_clicked_cb),
@@ -1830,12 +1797,7 @@ planner_resource_dialog_new (PlannerWindow *window,
 			  G_CALLBACK (resource_dialog_short_name_focus_in_cb),
 			  data);
 
-	resource_dialog_setup_option_menu (data->type_menu,
-					   NULL,
-					   NULL,
-					   _("Work"), MRP_RESOURCE_TYPE_WORK,
-					   _("Material"), MRP_RESOURCE_TYPE_MATERIAL,
-					   NULL);
+	resource_dialog_setup_combobox (data->type_menu);
 
 	/* Select the right type. */
 	switch (type) {
@@ -1848,7 +1810,7 @@ planner_resource_dialog_new (PlannerWindow *window,
 		break;
 	}
 
-	gtk_option_menu_set_history (GTK_OPTION_MENU (data->type_menu), index);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (data->type_menu), index);
 
 	g_signal_connect (data->type_menu,
 			  "changed",
@@ -1865,8 +1827,7 @@ planner_resource_dialog_new (PlannerWindow *window,
 		index = g_list_index (groups, group) + 1;
 	}
 
-	gtk_option_menu_set_history (GTK_OPTION_MENU (data->group_menu),
-				     index);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (data->group_menu), index);
 
 	g_signal_connect (data->group_menu,
 			  "changed",
@@ -1917,7 +1878,7 @@ planner_resource_dialog_new (PlannerWindow *window,
 
 	resource_dialog_update_title (data);
 
-	g_object_unref (glade);
+	g_object_unref (builder);
 
 	return dialog;
 }
