@@ -32,7 +32,6 @@
 #include <libplanner/mrp-project.h>
 #include "libplanner/mrp-paths.h"
 #include "planner-resource-view.h"
-#include "planner-cell-renderer-list.h"
 #include "planner-group-dialog.h"
 #include "planner-format.h"
 #include "planner-resource-dialog.h"
@@ -41,12 +40,13 @@
 #include "planner-property-dialog.h"
 #include "planner-resource-cmd.h"
 #include "planner-column-dialog.h"
+#include "planner-util.h"
 
 struct _PlannerResourceViewPriv {
-	GtkItemFactory         *popup_factory;
 	GtkTreeView            *tree_view;
 	GHashTable             *property_to_column;
 
+	GtkCellRenderer        *group_combo;
 	GtkWidget              *group_dialog;
 	GtkWidget              *resource_input_dialog;
 
@@ -67,6 +67,18 @@ enum {
 	NUM_OF_COLS
 };
 
+enum {
+	COLUMN_TYPE_TEXT,
+	COLUMN_TYPE_RESOURCE_TYPE,
+	NUM_TYPE_COLUMNS
+};
+
+enum {
+	COLUMN_GROUP_TEXT,
+	COLUMN_GROUP_GROUP,
+	NUM_GROUP_COLUMNS
+};
+
 static void           resource_view_finalize                 (GObject                 *object);
 static void           resource_view_insert_resource_cb       (GtkAction               *action,
 							      gpointer                 data);
@@ -76,15 +88,6 @@ static void           resource_view_remove_resource_cb       (GtkAction
 							      gpointer                 data);
 static void           resource_view_edit_resource_cb         (GtkAction               *action,
 							      gpointer                 data);
-static void           resource_view_popup_insert_resource_cb (gpointer                 callback_data,
-							      guint                    action,
-							      GtkWidget               *widget);
-static void           resource_view_popup_remove_resource_cb (gpointer                 callback_data,
-							      guint                    action,
-							      GtkWidget               *widget);
-static void           resource_view_popup_edit_resource_cb   (gpointer                 callback_data,
-							      guint                    action,
-							      GtkWidget               *widget);
 static void           resource_view_edit_columns_cb           (GtkAction              *action,
 							       gpointer                data);
 static void           resource_view_select_all_cb            (GtkAction               *action,
@@ -108,14 +111,19 @@ static void           resource_view_cell_email_edited        (GtkCellRendererTex
 							      gchar                   *path_string,
 							      gchar                   *new_text,
 							      gpointer                 user_data);
-static void           resource_view_cell_type_edited         (PlannerCellRendererList *cell,
+static void           resource_view_cell_type_changed        (GtkCellRendererCombo    *combo,
 							      gchar                   *path_string,
-							      gchar                   *new_text,
+							      GtkTreeIter             *new_iter,
 							      gpointer                 user_data);
-static void           resource_view_cell_group_edited        (PlannerCellRendererList *cell,
+static void           resource_view_cell_group_changed       (GtkCellRendererCombo    *combo,
 							      gchar                   *path_string,
-							      gchar                   *new_text,
+							      GtkTreeIter             *new_iter,
 							      gpointer                 user_data);
+static void           resource_view_cell_groups_changed_cb   (PlannerResourceView     *view,
+                                                              GParamSpec              *spec,
+                                                              gpointer                 user_data);
+static GtkTreeModel * resource_view_cell_group_create_model  (PlannerResourceView     *self,
+							      MrpProject              *project);
 static void           resource_view_cell_cost_edited         (GtkCellRendererText     *cell,
 							      gchar                   *path_string,
 							      gchar                   *new_text,
@@ -124,22 +132,7 @@ static void           resource_view_property_value_edited    (GtkCellRendererTex
 							      gchar                   *path_string,
 							      gchar                   *new_text,
 							      ColPropertyData         *data);
-static void           resource_view_cell_type_show_popup     (PlannerCellRendererList *cell,
-							      const gchar             *path_string,
-							      gint                     x1,
-							      gint                     y1,
-							      gint                     x2,
-							      gint                     y2,
-							      PlannerView             *view);
-static void           resource_view_cell_group_show_popup    (PlannerCellRendererList *cell,
-							      const gchar             *path_string,
-							      gint                     x1,
-							      gint                     y1,
-							      gint                     x2,
-							      gint                     y2,
-							      PlannerView             *view);
-static void           resource_view_cell_group_hide_popup    (PlannerCellRendererList *cell,
-							      PlannerView             *view);
+static GtkTreeModel * resource_view_cell_type_create_model   ();
 static void           resource_view_edit_groups_cb           (GtkAction               *action,
 							      gpointer                 data);
 static void           resource_view_project_loaded_cb        (MrpProject              *project,
@@ -256,26 +249,6 @@ static const GtkActionEntry entries[] = {
 	  G_CALLBACK (resource_view_edit_columns_cb) }
 };
 
-enum {
-	POPUP_NONE,
-	POPUP_INSERT,
-	POPUP_REMOVE,
-	POPUP_EDIT
-};
-
-#define GIF_CB(x) ((GtkItemFactoryCallback)(x))
-
-static GtkItemFactoryEntry popup_menu_items[] = {
-	{ N_("/_Insert resource"),   NULL, GIF_CB (resource_view_popup_insert_resource_cb),
-	  POPUP_INSERT,  "<Item>",       NULL
-	},
-	{ N_("/_Remove resource"),   NULL, GIF_CB (resource_view_popup_remove_resource_cb),
-	  POPUP_REMOVE,  "<StockItem>",  GTK_STOCK_DELETE
-	},
-	{ N_("/_Edit resource..."),  NULL, GIF_CB (resource_view_popup_edit_resource_cb),
-	  POPUP_EDIT,    "<Item>",       NULL }
-};
-
 /*
  * Commands
  */
@@ -362,11 +335,6 @@ resource_view_finalize (GObject *object)
 		resource_view_deactivate (PLANNER_VIEW (view));
 	}
 
-	if (view->priv->popup_factory) {
-		g_object_unref (view->priv->popup_factory);
-		view->priv->popup_factory = NULL;
-	}
-
 	if (view->priv->property_to_column) {
 		g_hash_table_unref (view->priv->property_to_column);
 		view->priv->property_to_column = NULL;
@@ -406,12 +374,6 @@ resource_view_activate (PlannerView *view)
 	gtk_widget_grab_focus (GTK_WIDGET (priv->tree_view));
 }
 
-static char *
-resource_view_item_factory_trans (const char *path, gpointer data)
-{
-	return _((gchar*) path);
-}
-
 static void
 resource_view_deactivate (PlannerView *view)
 {
@@ -434,20 +396,6 @@ resource_view_setup (PlannerView *view, PlannerWindow *main_window)
 
 	priv->property_to_column = g_hash_table_new (NULL, NULL);
 
-	priv->popup_factory = gtk_item_factory_new (GTK_TYPE_MENU,
-						    "<main>",
-						    NULL);
-
-	gtk_item_factory_set_translate_func (priv->popup_factory,
-					     resource_view_item_factory_trans,
-					     NULL,
-					     NULL);
-
-	gtk_item_factory_create_items (priv->popup_factory,
-				       G_N_ELEMENTS (popup_menu_items),
-				       popup_menu_items,
-				       view);
-
 	priv->ui_manager = planner_window_get_ui_manager (main_window);
 }
 
@@ -519,8 +467,7 @@ resource_view_get_widget (PlannerView *view)
 	PlannerResourceViewPriv *priv;
 	GtkWidget               *resource_table;
 	GtkWidget               *sw;
-	GtkWidget               *frame;
- 	GtkTreeModel            *model;
+	GtkTreeModel            *model;
 	MrpProject              *project;
 	GtkTreeSelection        *selection;
 
@@ -558,10 +505,20 @@ resource_view_get_widget (PlannerView *view)
 			  G_CALLBACK (resource_view_resource_removed_cb),
 			  view);
 
+	g_signal_connect_swapped (project,
+				  "group_added",
+				  G_CALLBACK (resource_view_cell_groups_changed_cb),
+				  view);
+	g_signal_connect_swapped (project,
+				  "group_removed",
+				  G_CALLBACK (resource_view_cell_groups_changed_cb),
+				  view);
+
 	model = GTK_TREE_MODEL (gtk_list_store_new (NUM_OF_COLS,
 						    G_TYPE_POINTER));
 
 	resource_table = gtk_tree_view_new_with_model (model);
+	g_object_unref (model);
 
 	priv->tree_view = GTK_TREE_VIEW (resource_table);
 
@@ -574,18 +531,15 @@ resource_view_get_widget (PlannerView *view)
 			  G_CALLBACK (resource_view_selection_changed_cb),
 			  view);
 
-	frame = gtk_frame_new (NULL);
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
-
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
 
 	gtk_container_add (GTK_CONTAINER (sw), resource_table);
-	gtk_container_add (GTK_CONTAINER (frame), sw);
 
-	return frame;
+	return sw;
 }
 
 static void
@@ -826,30 +780,6 @@ resource_view_get_type_enum (const gchar *type_str)
 
 /* Command callbacks. */
 
-static void
-resource_view_popup_insert_resource_cb  (gpointer   callback_data,
-					 guint      action,
-					 GtkWidget *widget)
-{
-	resource_view_insert_resource_cb (NULL, callback_data);
-}
-
-static void
-resource_view_popup_remove_resource_cb   (gpointer   callback_data,
-					  guint      action,
-					  GtkWidget *widget)
-{
-	resource_view_remove_resource_cb (NULL, callback_data);
-}
-
-static void
-resource_view_popup_edit_resource_cb     (gpointer   callback_data,
-					  guint      action,
-					  GtkWidget *widget)
-{
-	resource_view_edit_resource_cb (NULL, callback_data);
-}
-
 static void
 resource_view_insert_resource_cb (GtkAction *action,
 				  gpointer   data)
@@ -1136,10 +1066,10 @@ resource_view_button_press_event (GtkTreeView    *tv,
 {
 	PlannerResourceViewPriv *priv;
 	GtkTreePath             *path;
-	GtkItemFactory          *factory;
+	GtkUIManager            *ui_manager;
 
 	priv = PLANNER_RESOURCE_VIEW (view)->priv;
-	factory = priv->popup_factory;
+	ui_manager = priv->ui_manager;
 
 	if (event->button == 3) {
 		gtk_widget_grab_focus (GTK_WIDGET (tv));
@@ -1150,22 +1080,22 @@ resource_view_button_press_event (GtkTreeView    *tv,
 
 			gtk_tree_selection_select_path (gtk_tree_view_get_selection (tv), path);
 
-			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, POPUP_REMOVE), TRUE);
-			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, POPUP_EDIT), TRUE);
+			gtk_action_set_sensitive (
+				gtk_ui_manager_get_action (ui_manager, "/ResourceViewPopup/RemoveResource"), TRUE);
+			gtk_action_set_sensitive (
+				gtk_ui_manager_get_action (ui_manager, "/ResourceViewPopup/EditResource"), TRUE);
 			gtk_tree_path_free (path);
 		} else {
 			gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (tv));
 
-			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, POPUP_REMOVE), FALSE);
-			gtk_widget_set_sensitive (
-				gtk_item_factory_get_widget_by_action (factory, POPUP_EDIT), FALSE);
+			gtk_action_set_sensitive (
+				gtk_ui_manager_get_action (ui_manager, "/ResourceViewPopup/RemoveResource"), FALSE);
+			gtk_action_set_sensitive (
+				gtk_ui_manager_get_action (ui_manager, "/ResourceViewPopup/EditResource"), FALSE);
 		}
 
-		gtk_item_factory_popup (factory, event->x_root, event->y_root,
-					event->button, event->time);
+		gtk_menu_popup (GTK_MENU (gtk_ui_manager_get_widget (ui_manager, "/ResourceViewPopup")),
+				NULL, NULL, NULL, NULL, event->button, event->time);
 		return TRUE;
 	}
 
@@ -1175,11 +1105,14 @@ resource_view_button_press_event (GtkTreeView    *tv,
 static void
 resource_view_setup_tree_view (PlannerView *view)
 {
+	PlannerResourceView *resource_view;
 	GtkTreeView       *tree_view;
 	GtkTreeViewColumn *col;
+	GtkTreeModel      *model;
 	GtkCellRenderer   *cell;
 
-	tree_view = GTK_TREE_VIEW (PLANNER_RESOURCE_VIEW (view)->priv->tree_view);
+	resource_view = PLANNER_RESOURCE_VIEW (view);
+	tree_view = GTK_TREE_VIEW (resource_view->priv->tree_view);
 
 	gtk_tree_view_set_rules_hint (tree_view, TRUE);
 
@@ -1233,7 +1166,7 @@ resource_view_setup_tree_view (PlannerView *view)
 						 NULL, NULL);
 	g_object_set_data (G_OBJECT (col),
 			   "data-func", resource_view_short_name_data_func);
-	g_object_set_data (G_OBJECT (col), "id", "short_name");
+	g_object_set_data (G_OBJECT (col), "id", "short-name");
 
 	gtk_tree_view_append_column (tree_view, col);
 	g_signal_connect (col,
@@ -1247,12 +1180,23 @@ resource_view_setup_tree_view (PlannerView *view)
 			  view);
 
 	/* Type */
-	cell = planner_cell_renderer_list_new ();
-	g_object_set (cell, "editable", TRUE, NULL);
+	cell = gtk_cell_renderer_combo_new ();
+	model = resource_view_cell_type_create_model ();
+
+	g_object_set (cell,
+		      "editable", TRUE,
+		      "has-entry", FALSE,
+		      "model", model,
+		      "text-column", COLUMN_TYPE_TEXT,
+		      NULL);
+
+	g_object_unref (model);
 
 	col = gtk_tree_view_column_new_with_attributes (_("Type"), cell, NULL);
 	gtk_tree_view_column_set_resizable (col, TRUE);
 
+	/* TODO: Consider using "text" attribute instead of custom cell data
+	 * func, after making sure it works with the "data-func" property */
 	gtk_tree_view_column_set_cell_data_func (col, cell,
 						 resource_view_type_data_func,
 						 NULL, NULL);
@@ -1267,17 +1211,24 @@ resource_view_setup_tree_view (PlannerView *view)
 			  view);
 
 	g_signal_connect (cell,
-			  "edited",
-			  G_CALLBACK (resource_view_cell_type_edited),
-			  view);
-	g_signal_connect (cell,
-			  "show-popup",
-			  G_CALLBACK (resource_view_cell_type_show_popup),
+			  "changed",
+			  G_CALLBACK (resource_view_cell_type_changed),
 			  view);
 
 	/* Group */
-	cell = planner_cell_renderer_list_new ();
-	g_object_set (cell, "editable", TRUE, NULL);
+	cell = gtk_cell_renderer_combo_new ();
+	resource_view->priv->group_combo = cell;
+	model = resource_view_cell_group_create_model (resource_view,
+						       planner_window_get_project (view->main_window));
+
+	g_object_set (cell,
+		      "editable", TRUE,
+		      "has-entry", FALSE,
+		      "model", model,
+		      "text-column", COLUMN_GROUP_TEXT,
+		      NULL);
+
+	g_object_unref (model);
 
 	col = gtk_tree_view_column_new_with_attributes (_("Group"),
 							cell, NULL);
@@ -1297,17 +1248,9 @@ resource_view_setup_tree_view (PlannerView *view)
 			  view);
 
 	g_signal_connect (cell,
-			  "edited",
-			  G_CALLBACK (resource_view_cell_group_edited),
+			  "changed",
+			  G_CALLBACK (resource_view_cell_group_changed),
 			  view);
-	g_signal_connect (cell,
-			  "show-popup",
-			  G_CALLBACK (resource_view_cell_group_show_popup),
-			  view);
-	g_signal_connect_after (cell,
-				"hide-popup",
-				G_CALLBACK (resource_view_cell_group_hide_popup),
-				view);
 
 	/* Email */
 	cell = gtk_cell_renderer_text_new ();
@@ -1690,16 +1633,16 @@ resource_view_cell_cost_edited (GtkCellRendererText *cell,
 }
 
 static void
-resource_view_cell_type_edited (PlannerCellRendererList *cell,
-				gchar                   *path_string,
-				gchar                   *new_text,
-				gpointer                 user_data)
+resource_view_cell_type_changed (GtkCellRendererCombo *combo,
+                                 gchar                *path_string,
+                                 GtkTreeIter          *new_iter,
+                                 gpointer              user_data)
 {
 	PlannerView      *view;
 	MrpResource      *resource;
 	MrpResourceType   type;
 	GtkTreeView      *tree_view;
-	GtkTreeModel     *model;
+	GtkTreeModel     *model, *combo_model;
 	GtkTreePath      *path;
 	GtkTreeIter       iter;
 	GValue            value = { 0 };
@@ -1716,11 +1659,8 @@ resource_view_cell_type_edited (PlannerCellRendererList *cell,
 
 	gtk_tree_model_get (model, &iter, COL_RESOURCE, &resource, -1);
 
-	if (cell->selected_index == 0) {
-		type = MRP_RESOURCE_TYPE_WORK;
-	} else {
-		type = MRP_RESOURCE_TYPE_MATERIAL;
-	}
+	g_object_get (combo, "model", &combo_model, NULL);
+	gtk_tree_model_get (combo_model, new_iter, COLUMN_TYPE_RESOURCE_TYPE, &type, -1);
 
 	g_value_init (&value, G_TYPE_INT);
 	g_value_set_int (&value, type);
@@ -1730,63 +1670,41 @@ resource_view_cell_type_edited (PlannerCellRendererList *cell,
 	gtk_tree_path_free (path);
 }
 
-static void
-resource_view_cell_type_show_popup (PlannerCellRendererList *cell,
-				    const gchar        *path_string,
-				    gint                x1,
-				    gint                y1,
-				    gint                x2,
-				    gint                y2,
-				    PlannerView             *view)
+static GtkTreeModel *
+resource_view_cell_type_create_model ()
 {
-	GtkTreeView      *tree_view;
-	GtkTreeModel     *model;
-	GtkTreePath      *path;
-	GtkTreeIter       iter;
-	MrpResource      *resource;
-	GList            *list;
-	MrpResourceType   type;
+	GtkListStore *model;
+	GtkTreeIter   iter;
 
-	tree_view = GTK_TREE_VIEW (PLANNER_RESOURCE_VIEW (view)->priv->tree_view);
-	model = gtk_tree_view_get_model (tree_view);
+	/* TODO: Unify the model with the combobox in "Edit resource properties" */
+	model = gtk_list_store_new (NUM_TYPE_COLUMNS, G_TYPE_STRING, G_TYPE_INT);
 
-	path = gtk_tree_path_new_from_string (path_string);
-
-	gtk_tree_model_get_iter (model, &iter, path);
-
-	gtk_tree_model_get (model, &iter, COL_RESOURCE, &resource, -1);
-
-	list = NULL;
-	list = g_list_append (list, g_strdup (_("Work")));
-	list = g_list_append (list, g_strdup (_("Material")));
-
-	cell->list = list;
-
-	mrp_object_get (resource, "type", &type, NULL);
-
-	if (type == MRP_RESOURCE_TYPE_WORK) {
-		cell->selected_index = 0;
-	} else {
-		cell->selected_index = 1;
-	}
-
-	gtk_tree_path_free (path);
+	gtk_list_store_append (model, &iter);
+	gtk_list_store_set (model, &iter,
+			    COLUMN_TYPE_TEXT, _("Work"),
+			    COLUMN_TYPE_RESOURCE_TYPE, MRP_RESOURCE_TYPE_WORK,
+			    -1);
+	gtk_list_store_append (model, &iter);
+	gtk_list_store_set (model, &iter,
+			    COLUMN_TYPE_TEXT, _("Material"),
+			    COLUMN_TYPE_RESOURCE_TYPE, MRP_RESOURCE_TYPE_MATERIAL,
+			    -1);
+	return GTK_TREE_MODEL (model);
 }
 
 static void
-resource_view_cell_group_edited (PlannerCellRendererList *cell,
-				 gchar                   *path_string,
-				 gchar                   *new_text,
-				 gpointer                 user_data)
+resource_view_cell_group_changed (GtkCellRendererCombo *combo,
+                                  gchar                *path_string,
+                                  GtkTreeIter          *new_iter,
+                                  gpointer              user_data)
 {
 	PlannerView      *view;
 	MrpResource      *resource;
 	MrpGroup         *group;
 	GtkTreeView      *tree_view;
-	GtkTreeModel     *model;
+	GtkTreeModel     *model, *combo_model;
 	GtkTreePath      *path;
 	GtkTreeIter       iter;
-	GList            *list;
 	GValue            value = { 0 };
 
 	view = PLANNER_VIEW (user_data);
@@ -1801,15 +1719,8 @@ resource_view_cell_group_edited (PlannerCellRendererList *cell,
 
 	gtk_tree_model_get (model, &iter, COL_RESOURCE, &resource, -1);
 
-	list = g_list_nth (cell->user_data, cell->selected_index);
-	if (list == NULL) {
-		/* We should probably parse the string here and set
-		 * the right group. See #110.
-		 */
-		return;
-	}
-
-	group = list->data;
+	g_object_get (combo, "model", &combo_model, NULL);
+	gtk_tree_model_get (combo_model, new_iter, COLUMN_GROUP_GROUP, &group, -1);
 
 	g_value_init (&value, MRP_TYPE_GROUP);
 	g_value_set_object (&value, group);
@@ -1913,88 +1824,66 @@ resource_view_property_value_edited (GtkCellRendererText *cell,
 }
 
 static void
-resource_view_cell_group_show_popup (PlannerCellRendererList *cell,
-				     const gchar        *path_string,
-				     gint                x1,
-				     gint                y1,
-				     gint                x2,
-				     gint                y2,
-				     PlannerView        *view)
+resource_view_tree_setup_groups_model (PlannerResourceView *self,
+                                       MrpProject          *project)
 {
-	GtkTreeView      *tree_view;
-	GtkTreeModel     *model;
-	GtkTreeIter       iter;
-	GtkTreePath      *path;
-	GList            *list;
-	MrpProject       *project;
-	MrpResource      *resource;
-	MrpGroup         *group;
-	MrpGroup         *current_group;
-	GList            *groups, *l;
-	gchar            *name;
-	gint              i, index;
+	GtkTreeModel *model;
 
-	tree_view = PLANNER_RESOURCE_VIEW (view)->priv->tree_view;
-
-	model = gtk_tree_view_get_model (tree_view);
-
-	path = gtk_tree_path_new_from_string (path_string);
-
-	gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path);
-
-
-	project = planner_window_get_project (view->main_window);
-
-	gtk_tree_model_get (model, &iter, COL_RESOURCE, &resource, -1);
-
-	mrp_object_get (resource,
-			"group", &current_group,
-			NULL);
-
-	i = 0;
-	index = 0;
-	list = NULL;
-	groups = g_list_copy (mrp_project_get_groups (project));
-	groups = g_list_prepend (groups, NULL);
-
-	for (l = groups; l; l = l->next) {
-		group = l->data;
-
-		if (group != NULL) {
-			mrp_object_get (group, "name", &name, NULL);
-			g_object_ref (group);
-		} else {
-			name = g_strdup (_("(None)"));
-		}
-
-		list = g_list_prepend (list, name);
-
-		if (current_group == group) {
-			index = i;
-		}
-
-		i++;
-	}
-
-	cell->list = g_list_reverse (list);
-	cell->user_data = groups;
-	cell->selected_index = index;
+	model = resource_view_cell_group_create_model (self, project);
+	g_object_set (self->priv->group_combo, "model", model, NULL);
+	g_object_unref (model);
 }
 
 static void
-resource_view_cell_group_hide_popup (PlannerCellRendererList *cell,
-				     PlannerView             *view)
+resource_view_cell_groups_changed_cb (PlannerResourceView *view,
+                                      GParamSpec          *spec,
+                                      gpointer             user_data)
 {
-	GList *l;
+	MrpProject *project;
 
-	for (l = cell->user_data; l; l = l->next) {
-		if (l->data) {
-			g_object_unref (l->data);
-		}
+	project = planner_window_get_project (PLANNER_VIEW (view)->main_window);
+	resource_view_tree_setup_groups_model (view, project);
+}
+
+static GtkTreeModel *
+resource_view_cell_group_create_model (PlannerResourceView *view,
+                                       MrpProject          *project)
+{
+	GtkListStore *model;
+	GtkTreeIter   iter;
+	GList        *groups, *l;
+	MrpGroup     *group;
+	gchar        *group_name;
+
+	/* TODO: Unify the model with the combobox in "Edit resource properties" */
+	model = gtk_list_store_new (NUM_GROUP_COLUMNS, G_TYPE_STRING, MRP_TYPE_GROUP);
+
+	gtk_list_store_append (model, &iter);
+	gtk_list_store_set (model, &iter,
+			    COLUMN_GROUP_TEXT, _("(None)"),
+			    COLUMN_GROUP_GROUP, NULL,
+			    -1);
+
+	groups = mrp_project_get_groups (project);
+
+	for (l = groups; l; l = l->next) {
+		group = l->data;
+		mrp_object_get (group, "name", &group_name, NULL);
+
+		gtk_list_store_append (model, &iter);
+		gtk_list_store_set (model, &iter,
+				    COLUMN_GROUP_TEXT, group_name,
+				    COLUMN_GROUP_GROUP, group,
+				    -1);
+		g_free (group_name);
+
+		g_signal_connect_swapped (group,
+					  "notify::name",
+					  G_CALLBACK (resource_view_cell_groups_changed_cb),
+					  view);
 	}
 
-	g_list_free (cell->user_data);
-	cell->user_data = NULL;
+	return GTK_TREE_MODEL (model);
 }
 
 static void
@@ -2021,11 +1910,13 @@ resource_view_edit_groups_cb (GtkAction *action,
 static void
 resource_view_project_loaded_cb (MrpProject *project, PlannerView *view)
 {
+	PlannerResourceView *resource_view;
 	GtkTreeModel *model;
 	GList        *resources, *l;
 	GtkTreeView  *tree_view;
 
-	tree_view = PLANNER_RESOURCE_VIEW (view)->priv->tree_view;
+	resource_view = PLANNER_RESOURCE_VIEW (view);
+	tree_view = resource_view->priv->tree_view;
 
 	model = GTK_TREE_MODEL (gtk_list_store_new (NUM_OF_COLS,
 						    G_TYPE_POINTER));
@@ -2041,8 +1932,9 @@ resource_view_project_loaded_cb (MrpProject *project, PlannerView *view)
 				    -1);
 	}
 	gtk_tree_view_set_model (tree_view, model);
+	g_object_unref (model);
 
- 	g_object_unref (model);
+	resource_view_tree_setup_groups_model (resource_view, project);
 }
 
 static void
@@ -2151,41 +2043,14 @@ resource_view_popup_menu (GtkWidget   *widget,
 {
 	PlannerResourceViewPriv   *priv;
 	GtkTreeView       *tree;
-	GtkTreePath       *path;
-	GtkTreeViewColumn *column;
-	GdkRectangle       rect;
-	gint               x, y;
 
 	priv = PLANNER_RESOURCE_VIEW (view)->priv;
 	tree = GTK_TREE_VIEW (priv->tree_view);
 
-	gtk_tree_view_get_cursor (tree, &path, &column);
-	gtk_tree_view_get_cell_area (tree,
-				     path,
-				     column,
-				     &rect);
-
-	x = rect.x;
-	y = rect.y;
-
-	/* Note: this is not perfect, but good enough for now. */
-	gdk_window_get_root_origin (GTK_WIDGET (tree)->window, &x, &y);
-	rect.x += x;
-	rect.y += y;
-
-	gtk_widget_translate_coordinates (GTK_WIDGET (tree),
-					  gtk_widget_get_toplevel (GTK_WIDGET (tree)),
-					  rect.x, rect.y,
-					  &x, &y);
-
-	/* Offset so it's not overlapping the cell. */
-	rect.x = x + 20;
-	rect.y = y + 20;
-
-	gtk_item_factory_popup (priv->popup_factory,
-				rect.x, rect.y,
-				0,
-				gtk_get_current_event_time ());
+	gtk_menu_popup (GTK_MENU (gtk_ui_manager_get_widget (priv->ui_manager, "ResourceViewPopup")),
+			NULL, NULL,
+			planner_util_menu_position_on_current_cell, tree,
+			0, gtk_get_current_event_time ());
 }
 
 static void
@@ -2435,55 +2300,21 @@ resource_view_save_columns (PlannerResourceView *view)
 	priv = view->priv;
 
 	planner_view_column_save_helper (PLANNER_VIEW (view),
-					 GTK_TREE_VIEW (priv->tree_view));
+					 GTK_TREE_VIEW (priv->tree_view),
+					 "res");
 }
 
 static void
 resource_view_load_columns (PlannerResourceView *view)
 {
 	PlannerResourceViewPriv *priv;
-	GList                   *columns, *l;
-	GtkTreeViewColumn       *column;
-	const gchar             *id;
-	gint                     i;
 
 	priv = view->priv;
 
 	/* Load the columns. */
 	planner_view_column_load_helper (PLANNER_VIEW (view),
-					 GTK_TREE_VIEW (priv->tree_view));
-
-	/* Make things a bit more robust by setting defaults if we don't get any
-	 * visible columns. Should be done through a schema instead (but we'll
-	 * keep this since a lot of people get bad installations when installing
-	 * themselves).
-	 */
-	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (priv->tree_view));
-	i = 0;
-	for (l = columns; l; l = l->next) {
-		if (gtk_tree_view_column_get_visible (l->data)) {
-			i++;
-		}
-	}
-
-	if (i == 0) {
-		for (l = columns; l; l = l->next) {
-			column = l->data;
-
-			if (g_object_get_data (G_OBJECT (column), "custom")) {
-				continue;
-			}
-
-			id = g_object_get_data (G_OBJECT (column), "id");
-			if (!id) {
-				continue;
-			}
-
-			gtk_tree_view_column_set_visible (column, TRUE);
-		}
-	}
-
-	g_list_free (columns);
+					 GTK_TREE_VIEW (priv->tree_view),
+					 "res");
 }
 
 PlannerView *
