@@ -13,28 +13,22 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __PLANNER_TASK_POPUP_H__
 #define __PLANNER_TASK_POPUP_H__
 
 #include <gtk/gtk.h>
+#include "planner-task-tree.h"
 
-typedef enum {
-	PLANNER_TASK_POPUP_NONE,
-	PLANNER_TASK_POPUP_INSERT,
-	PLANNER_TASK_POPUP_SUBTASK,
-	PLANNER_TASK_POPUP_REMOVE,
-	PLANNER_TASK_POPUP_UNLINK,
-	PLANNER_TASK_POPUP_EDIT_TASK,
-	PLANNER_TASK_POPUP_EDIT_RESOURCES
-} PlannerTaskPopupItem;
-
-GtkItemFactory *planner_task_popup_new               (PlannerTaskTree *tree);
-void            planner_task_popup_update_sensitivity (GtkItemFactory  *factory,
-						      GList           *tasks);
+GtkUIManager *planner_task_popup_new                (PlannerTaskTree *tree);
+void          planner_task_popup_set_sensitive      (GtkUIManager *ui_manager,
+						     const gchar *path,
+						     gboolean sensitive);
+void          planner_task_popup_update_sensitivity (GtkUIManager    *ui_manager,
+						     GList           *tasks);
 
 
 #endif
