@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -43,7 +43,7 @@ struct _PlannerUsageViewPriv {
 	GtkUIManager           *ui_manager;
 	GtkActionGroup         *actions;
 	guint                   merged_id;
-	gulong                  expose_id;
+	gulong                  draw_signal_id;
 };
 
 static void         usage_view_finalize                (GObject           *object);
@@ -61,8 +61,8 @@ static void         usage_view_resource_added_cb       (MrpProject        *proje
 							PlannerView       *view);
 static void         usage_view_project_loaded_cb       (MrpProject        *project,
 							PlannerView       *view);
-static gboolean     usage_view_expose_cb               (GtkWidget         *widget,
-							GdkEventExpose    *event,
+static gboolean     usage_view_draw_cb                 (GtkWidget         *widget,
+							cairo_t           *cr,
 							gpointer           user_data);
 static void         usage_view_tree_style_set_cb       (GtkWidget         *tree,
 							GtkStyle          *prev_style,
@@ -128,24 +128,36 @@ usage_view_chart_scroll_event (GtkWidget * gki, GdkEventScroll * event, PlannerV
 
 	gboolean can_in, can_out;
 	PlannerUsageViewPriv *priv;
+	gdouble delta_y;
 
 	if (event->state & GDK_CONTROL_MASK) {
 		priv = PLANNER_USAGE_VIEW (view)->priv;
 		planner_usage_chart_can_zoom (priv->chart, &can_in, &can_out);
+		/* TODO: Why is the canvas area getting GDK_SCROLL_SMOOTH but header not? */
 		switch (event->direction) {
-      			case GDK_SCROLL_UP: {
+			case GDK_SCROLL_UP: {
 				dontpropagate = TRUE;
 				if (can_in)
 					usage_view_zoom_in_cb  (NULL, view);
-	        		break;
+				break;
 			}
 			case GDK_SCROLL_DOWN:
 				dontpropagate = TRUE;
 				if (can_out)
 					usage_view_zoom_out_cb  (NULL, view);
-			        break;
-		      default:
-        		break;
+				break;
+			case GDK_SCROLL_SMOOTH:
+				/* TODO: Test over with different input methods (that give values other than 1 or -1),
+				* possibly gather deltas together to handle the smoothness */
+				/* TODO: First wheel event seems to carry a delta of zero and thus do nothing */
+				gdk_event_get_scroll_deltas ((GdkEvent *)event, NULL, &delta_y);
+				if (can_in && delta_y < 0)
+					usage_view_zoom_in_cb (NULL, view);
+				else if (can_out && delta_y > 0)
+					usage_view_zoom_out_cb (NULL, view);
+				break;
+			default:
+				break;
 		}
     	}
 
@@ -381,38 +393,6 @@ usage_view_edit_columns_cb (GtkAction *action,
 				    GTK_TREE_VIEW (priv->tree));
 }
 
-static void
-usage_view_tree_view_size_request_cb (GtkWidget      *widget,
-				      GtkRequisition *req,
-				      gpointer        data)
-{
-        req->height = -1;
-}
-
-static gboolean
-usage_view_tree_view_scroll_event_cb (GtkWidget      *widget,
-				      GdkEventScroll *event,
-				      gpointer        data)
-{
-        GtkAdjustment *adj;
-        GtkTreeView *tv = GTK_TREE_VIEW (widget);
-        gdouble new_value;
-        if (event->direction != GDK_SCROLL_UP &&
-            event->direction != GDK_SCROLL_DOWN) {
-                return FALSE;
-        }
-        adj = gtk_tree_view_get_vadjustment (tv);
-        if (event->direction == GDK_SCROLL_UP) {
-                new_value = adj->value - adj->page_increment / 2;
-        } else {
-                new_value = adj->value + adj->page_increment / 2;
-        }
-        new_value =
-                CLAMP (new_value, adj->lower, adj->upper - adj->page_size);
-        gtk_adjustment_set_value (adj, new_value);
-        return TRUE;
-}
-
 static void
 usage_view_tree_view_columns_changed_cb (GtkTreeView      *tree_view,
 					 PlannerUsageView *view)
@@ -438,14 +418,11 @@ usage_view_create_widget (PlannerView *view)
         PlannerUsageViewPriv *priv;
         MrpProject           *project;
         GtkWidget            *hpaned;
-        GtkWidget            *left_frame;
-        GtkWidget            *right_frame;
         PlannerUsageModel    *model;
         GtkWidget            *tree;
-        GtkWidget            *vbox;
         GtkWidget            *sw;
         GtkWidget            *chart;
-	GtkAdjustment        *hadj, *vadj;
+	GtkAdjustment        *vadj;
 
         project = planner_window_get_project (view->main_window);
         priv = PLANNER_USAGE_VIEW (view)->priv;
@@ -464,18 +441,16 @@ usage_view_create_widget (PlannerView *view)
         model = planner_usage_model_new (project);
         tree = planner_usage_tree_new (view->main_window, model);
         priv->tree = tree;
-        left_frame = gtk_frame_new (NULL);
-        right_frame = gtk_frame_new (NULL);
+        hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 
-        vbox = gtk_vbox_new (FALSE, 3);
-        gtk_box_pack_start (GTK_BOX (vbox), tree, TRUE, TRUE, 0);
-        hadj = gtk_tree_view_get_hadjustment (GTK_TREE_VIEW (tree));
-        gtk_box_pack_start (GTK_BOX (vbox), gtk_hscrollbar_new (hadj), FALSE,
-                            TRUE, 0);
-        gtk_container_add (GTK_CONTAINER (left_frame), vbox);
-
-        hadj = GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 0, 90, 250, 2000));
-        vadj = gtk_tree_view_get_vadjustment (GTK_TREE_VIEW (tree));
+	sw = gtk_scrolled_window_new (NULL, NULL);
+	/* TODO: Consider changing vertical policy to GTK_POLICY_EXTERNAL once we depend on gtk 3.16 */
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+					GTK_POLICY_AUTOMATIC,
+					GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
+	gtk_container_add (GTK_CONTAINER (sw), tree);
+	gtk_paned_add1 (GTK_PANED (hpaned), sw);
 
         chart = planner_usage_chart_new_with_model (GTK_TREE_MODEL (model));
         priv->chart = PLANNER_USAGE_CHART (chart);
@@ -488,18 +463,14 @@ usage_view_create_widget (PlannerView *view)
 	g_signal_connect (priv->chart, "scroll-event",
                     G_CALLBACK (usage_view_chart_scroll_event), view);
 
-        sw = gtk_scrolled_window_new (hadj, vadj);
+	vadj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (sw));
+        sw = gtk_scrolled_window_new (NULL, vadj);
         gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
-                                        GTK_POLICY_ALWAYS,
+                                        GTK_POLICY_AUTOMATIC,
                                         GTK_POLICY_AUTOMATIC);
-        gtk_container_add (GTK_CONTAINER (right_frame), sw);
+        gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
         gtk_container_add (GTK_CONTAINER (sw), chart);
-
-        hpaned = gtk_hpaned_new ();
-        gtk_frame_set_shadow_type (GTK_FRAME (left_frame), GTK_SHADOW_IN);
-        gtk_frame_set_shadow_type (GTK_FRAME (right_frame), GTK_SHADOW_IN);
-        gtk_paned_add1 (GTK_PANED (hpaned), left_frame);
-        gtk_paned_add2 (GTK_PANED (hpaned), right_frame);
+        gtk_paned_add2 (GTK_PANED (hpaned), sw);
 
 	usage_view_load_columns (PLANNER_USAGE_VIEW (view));
 
@@ -529,16 +500,6 @@ usage_view_create_widget (PlannerView *view)
 			  "status_updated",
                           G_CALLBACK (usage_view_usage_status_updated),
                           view);
-        g_signal_connect_after (tree,
-				"size_request",
-                                G_CALLBACK
-                                (usage_view_tree_view_size_request_cb),
-                                NULL);
-        g_signal_connect_after (tree,
-				"scroll_event",
-                                G_CALLBACK
-                                (usage_view_tree_view_scroll_event_cb),
-                                view);
 	g_signal_connect (tree,
 			  "style_set",
 			  G_CALLBACK (usage_view_tree_style_set_cb),
@@ -588,7 +549,7 @@ usage_view_update_row_and_header_height (PlannerView *view)
 	for (l = cols; l; l = l->next) {
 		col = l->data;
 
-		gtk_widget_size_request (col->button, &req);
+		gtk_widget_get_preferred_size (gtk_tree_view_column_get_button (col), &req, NULL);
 		header_height = MAX (header_height, req.height);
 
 		gtk_tree_view_column_cell_get_size (col,
@@ -620,16 +581,16 @@ usage_view_update_row_and_header_height (PlannerView *view)
 }
 
 static gboolean
-usage_view_expose_cb (GtkWidget      *widget,
-		      GdkEventExpose *event,
-		      gpointer        data)
+usage_view_draw_cb (GtkWidget *widget,
+                    cairo_t   *cr,
+                    gpointer   data)
 {
 	PlannerUsageView     *view = PLANNER_USAGE_VIEW (data);
 
 	usage_view_update_row_and_header_height (PLANNER_VIEW(view));
 
 	g_signal_handler_disconnect (view->priv->tree,
-				     view->priv->expose_id);
+				     view->priv->draw_signal_id);
 
 	return FALSE;
 }
@@ -662,11 +623,11 @@ usage_view_resource_added_cb (MrpProject  *project,
 
 	priv = PLANNER_USAGE_VIEW (view)->priv;
 
-	if (priv->expose_id == 0) {
-		priv->expose_id = g_signal_connect_after (priv->tree,
-							  "expose_event",
-							  G_CALLBACK (usage_view_expose_cb),
-							  view);
+	if (priv->draw_signal_id == 0) {
+		priv->draw_signal_id = g_signal_connect_after (priv->tree,
+							       "draw",
+							       G_CALLBACK (usage_view_draw_cb),
+							       view);
 	}
 }
 
@@ -698,10 +659,10 @@ usage_view_project_loaded_cb (MrpProject *project, PlannerView *view)
 				      PLANNER_USAGE_MODEL (model));
         planner_usage_chart_set_model (PLANNER_USAGE_CHART (priv->chart), model);
 
-	priv->expose_id = g_signal_connect_after (priv->tree,
-						  "expose_event",
-						  G_CALLBACK (usage_view_expose_cb),
-						  view);
+	priv->draw_signal_id = g_signal_connect_after (priv->tree,
+						       "draw",
+						       G_CALLBACK (usage_view_draw_cb),
+						       view);
 
 	g_object_unref (model);
 
@@ -789,55 +750,19 @@ usage_view_save_columns (PlannerUsageView *view)
 	priv = view->priv;
 
 	planner_view_column_save_helper (PLANNER_VIEW (view),
-					 GTK_TREE_VIEW (priv->tree));
+					 GTK_TREE_VIEW (priv->tree), "usage");
 }
 
 static void
 usage_view_load_columns (PlannerUsageView *view)
 {
 	PlannerUsageViewPriv *priv;
-	GList                *columns, *l;
-	GtkTreeViewColumn    *column;
-	const gchar          *id;
-	gint                  i;
 
 	priv = view->priv;
 
 	/* Load the columns. */
 	planner_view_column_load_helper (PLANNER_VIEW (view),
-					 GTK_TREE_VIEW (priv->tree));
-
-	/* Make things a bit more robust by setting defaults if we don't get any
-	 * visible columns. Should be done through a schema instead (but we'll
-	 * keep this since a lot of people get bad installations when installing
-	 * themselves).
-	 */
-	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (priv->tree));
-	i = 0;
-	for (l = columns; l; l = l->next) {
-		if (gtk_tree_view_column_get_visible (l->data)) {
-			i++;
-		}
-	}
-
-	if (i == 0) {
-		for (l = columns; l; l = l->next) {
-			column = l->data;
-
-			if (g_object_get_data (G_OBJECT (column), "custom")) {
-				continue;
-			}
-
-			id = g_object_get_data (G_OBJECT (column), "id");
-			if (!id) {
-				continue;
-			}
-
-			gtk_tree_view_column_set_visible (column, TRUE);
-		}
-	}
-
-	g_list_free (columns);
+					 GTK_TREE_VIEW (priv->tree), "usage");
 }
 
 PlannerView *
