@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __PLANNER_UTIL_H__
@@ -28,5 +28,11 @@ void planner_util_show_help (GtkWindow    *parent);
 void planner_util_show_url  (GtkWindow    *parent,
                              const gchar  *url);
 
+void planner_util_menu_position_on_current_cell (GtkMenu  *menu,
+                                                 gint     *x,
+                                                 gint     *y,
+                                                 gboolean *push_in,
+                                                 gpointer  user_data);
+
 #endif /* __PLANNER_UTIL_H__ */
 
